@@ -10,12 +10,6 @@
 
 set -e
 
-if autoconf --version | head -1 | grep '2\.5' > /dev/null 2>&1; then
-  cp configure.in-v2.50 configure.in
-else
-  cp configure.in-v2.13 configure.in
-fi
-
 automake --version | perl -ne 'if (/\(GNU automake\) ([0-9].[0-9])/) {print;  if ($1 < 1.4) {exit 1;}}'
 
 if [ $? -ne 0 ]; then
@@ -28,8 +22,6 @@ if test ! -d `aclocal --print-ac-dir`; then
   exit 1
 fi
 
-echo "Selecting the correct m4 script..."
-
 for script in `cd ac-helpers/fallback; echo *.m4`; do
   if test -r `aclocal --print-ac-dir`/$script; then
     # Perhaps it was installed recently
