@@ -513,7 +513,7 @@ void GR_Font::s_getGenericFontProperties(const char *szFontName, FontFamilyEnum
 /***
  Draw Operations
 ***/
-void GR_QNXGraphics::setColor(UT_RGBColor& clr)
+void GR_QNXGraphics::setColor(const UT_RGBColor& clr)
 {
 	//printf("GR: setColor %d %d %d \n", clr.m_red, clr.m_blu, clr.m_grn);
 	m_currentColor = PgRGB(clr.m_red, clr.m_grn, clr.m_blu);
@@ -844,9 +844,16 @@ void GR_QNXGraphics::setCursor(GR_Graphics::Cursor c)
 		break;
 
 	case GR_CURSOR_RIGHTARROW:
-		cursor_number = GDK_ARROW;
+		cursor_number = GDK_SB_RIGHT_ARROW; //GDK_ARROW;
 		break;
 		
+#ifdef BIDI_ENABLED
+//#error choose a suitable cursor; this is just a placeholder !!!		
+	case GR_CURSOR_LEFTARROW:
+		cursor_number = GDK_SB_LEFT_ARROW; //GDK_ARROW;
+		break;
+#endif
+
 	case GR_CURSOR_IMAGE:
 		cursor_number = GDK_FLEUR;
 		break;
