@@ -81,10 +81,14 @@ GR_UnixGraphics::GR_UnixGraphics(GdkWindow * win, XAP_UnixFontManager * fontMana
 
 	gdk_gc_set_function(m_pXORGC, GDK_XOR);
 
-	GdkColor clrWhite;
+ 	GdkColor clrWhite;
 	gdk_color_white(m_pColormap, &clrWhite);
 	gdk_gc_set_foreground(m_pXORGC, &clrWhite);
 
+ 	GdkColor clrBlack;
+	gdk_color_black(m_pColormap, &clrBlack);
+	gdk_gc_set_foreground(m_pGC, &clrBlack);
+
 	// I only want to set CAP_NOT_LAST, but the call takes all
 	// arguments (and doesn't have a default value).  Set the
 	// line attributes to not draw the last pixel.
@@ -457,7 +461,7 @@ UT_uint32 GR_UnixGraphics::_getResolution(void) const
 	return 100;
 }
 
-void GR_UnixGraphics::setColor(UT_RGBColor& clr)
+void GR_UnixGraphics::setColor(const UT_RGBColor& clr)
 {
 	UT_ASSERT(m_pGC);
 	GdkColor c;
@@ -960,6 +964,12 @@ void GR_UnixGraphics::drawImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest
 
    	Fatmap * image = pUnixImage->getData();
 
+	if (image == 0)
+	{
+		UT_DEBUGMSG(("Found no image data. This is probably SVG masquerading as a raster!\n"));
+		return;
+	}
+
    	UT_sint32 iImageWidth = pUnixImage->getDisplayWidth();
    	UT_sint32 iImageHeight = pUnixImage->getDisplayHeight();
 
@@ -1004,6 +1014,8 @@ void GR_UnixGraphics::drawImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDest
 
 	GdkPixbuf * image = pUnixImage->getData();
 
+	UT_ASSERT(image);
+
    	UT_sint32 iImageWidth = pUnixImage->getDisplayWidth();
    	UT_sint32 iImageHeight = pUnixImage->getDisplayHeight();
 	
@@ -1066,10 +1078,21 @@ void GR_UnixGraphics::setCursor(GR_Graphics::Cursor c)
 		cursor_number = GDK_XTERM;
 		break;
 
+	//I have changed the shape of the arrow so get a consistent
+	//behaviour in the bidi build; I think the new arrow is better
+	//for the purpose anyway
+	
 	case GR_CURSOR_RIGHTARROW:
-		cursor_number = GDK_ARROW;
+		cursor_number = GDK_SB_RIGHT_ARROW; //GDK_ARROW;
 		break;
-		
+
+#ifdef BIDI_ENABLED
+//#error choose a suitable cursor; this is just a placeholder !!!		
+	case GR_CURSOR_LEFTARROW:
+		cursor_number = GDK_SB_LEFT_ARROW; //GDK_LEFT_PTR;
+		break;
+#endif		
+
 	case GR_CURSOR_IMAGE:
 		cursor_number = GDK_FLEUR;
 		break;
