@@ -415,7 +415,7 @@ UT_uint32 GR_Win32Graphics::_getResolution(void) const
 	return result;
 }
 
-void GR_Win32Graphics::setColor(UT_RGBColor& clr)
+void GR_Win32Graphics::setColor(const UT_RGBColor& clr)
 {
 	_setColor(RGB(clr.m_red, clr.m_grn, clr.m_blu));
 }
@@ -795,6 +795,13 @@ void GR_Win32Graphics::handleSetCursorMessage(void)
 		cursor_name = IDC_ARROW;		// TODO change this
 		break;
 		
+#ifdef BIDI_ENABLED
+//#error choose a suitable cursor; this is just a placeholder !!!		
+	case GR_CURSOR_LEFTARROW:
+		cursor_name = IDC_ARROW;		// TODO change this
+		break;
+#endif
+
 	case GR_CURSOR_IMAGE:
 		cursor_name = IDC_SIZEALL;
 		break;
