@@ -89,7 +89,7 @@ public:
 	UT_uint32 getMaxCharacterWidth(const UT_UCSChar*s, UT_uint32 Length);
 	UT_uint32 getAppropriateFontSizeFromString(const char * pszFontSize);
 
-	virtual void setColor(UT_RGBColor& clr) = 0;
+	virtual void setColor(const UT_RGBColor& clr) = 0;
 	
 	virtual GR_Font* getGUIFont() = 0;
 	virtual GR_Font* findFont(
@@ -172,6 +172,9 @@ public:
 				   GR_CURSOR_UPDOWN,
 				   GR_CURSOR_EXCHANGE,
 				   GR_CURSOR_GRAB
+#ifdef BIDI_ENABLED
+					,GR_CURSOR_LEFTARROW
+#endif
 	} Cursor;
 
 	virtual void setCursor(GR_Graphics::Cursor c) = 0;
