@@ -1,4 +1,5 @@
-/* AbiSource Program Utilities
+/* 
+ * AbiSource Program Utilities
  * Copyright (C) 2001 Dom Lachowicz <dominicl@seas.upenn.edu>
  * 
  * This program is free software; you can redistribute it and/or
@@ -43,10 +44,22 @@
 // -DAL-
 //
 
-#if defined(_MSC_VER) && !(_MSC_VER > 1100)		// MSVC 5 and lower
-#define ABI_DOESNT_SUPPORT_EXCEPTIONS = 1
+#if defined(_MSC_VER) 
+	#define ABI_DOESNT_SUPPORT_THROWS = 1
 #endif
 
+/*
+ * Public base-class which all of our own 
+ * exceptions should inherit from
+ */
+class UT_Exception
+{
+ public:
+  UT_Exception () {}
+  virtual ~UT_Exception () {}
+};
+
+//
 // UT_TRY will begin a 'try' block
 // UT_CATCH will 'catch' a specific exception type
 // UT_END_CATCH evaluates to nothing, basically, but use it
@@ -56,6 +69,9 @@
 // UT_THROWS will declare a C++ method as throwing an exception
 //           usage:
 //           UT_THROWS((MyException1, MyException2))
+// UT_RETHROW will rethrow a caught exception from within the 
+//            exception handler
+//
 
 #ifdef ABI_DOESNT_SUPPORT_EXCEPTIONS
 
@@ -75,7 +91,7 @@
 #define UT_END_CATCH    }
 #define UT_THROW(x)     (void)0
 #define UT_CATCH_ANY    (void)0
-#define UT_RETHROW      (void)0;
+#define UT_RETHROW      (void)0
 
 #else
 
