@@ -310,7 +310,7 @@ gint XAP_UnixFrame::_fe::delete_event(GtkWidget * w, GdkEvent * /*event*/, gpoin
 	const EV_EditMethodContainer * pEMC = pApp->getEditMethodContainer();
 	UT_ASSERT(pEMC);
 	
-	const EV_EditMethod * pEM = pEMC->findEditMethodByName("closeWindow");
+	const EV_EditMethod * pEM = pEMC->findEditMethodByName("closeWindowX");
 	UT_ASSERT(pEM);
 	
 	if (pEM)
@@ -750,6 +750,11 @@ bool XAP_UnixFrame::openURL(const char * szURL)
 		fmtstring = "konqueror %s &";
 		execstring = g_strdup_printf(fmtstring, szURL);
 	}
+	else if(progExists("galeon"))
+	{
+	  	fmtstring = "galeon %s &";
+		execstring = g_strdup_printf(fmtstring, szURL);
+	}
 	// Anyone know how to find out where it might be, regardless?
 	else if(progExists("mozilla"))
 	{
@@ -767,11 +772,21 @@ bool XAP_UnixFrame::openURL(const char * szURL)
 		fmtstring = "khelpcenter %s &";
 		execstring = g_strdup_printf(fmtstring, szURL);
 	}
-	else
+	else if(progExists("gnome-help-browser"))
+	{
+		fmtstring = "gnome-help-browser %s &";
+		execstring = g_strdup_printf(fmtstring, szURL);
+	}
+	else if(progExists("lynx"))
 	{
 		fmtstring = "xterm -e lynx %s &";
 		execstring = g_strdup_printf(fmtstring, szURL);
 	}
+	else if(progExists("w3m"))
+	{
+		fmtstring = "xterm -e w3m %s &";
+ 		execstring = g_strdup_printf(fmtstring, szURL);
+ 	}
 
 	system(execstring);
 	g_free (execstring);
@@ -875,6 +890,11 @@ EV_Toolbar * XAP_UnixFrame::_newToolbar(XAP_App *app, XAP_Frame *frame,
 
 void XAP_UnixFrame::queue_resize()
 {
-	UT_DEBUGMSG(("XAP_UnixFrame::queue_resize\n"));	
+	xxx_UT_DEBUGMSG(("XAP_UnixFrame::queue_resize\n"));	
 	gtk_widget_queue_resize(m_wTopLevelWindow);
 }
+
+EV_Menu* XAP_UnixFrame::getMainMenu()
+{
+	return m_pUnixMenu;
+}
