@@ -94,6 +94,8 @@ void XAP_Win32Dialog_FileOpenSaveAs::_buildFilterList(UT_String& sFilter)
 {
 	UT_String sAllSuffixes;
 
+	const XAP_StringSet*  pSS   = XAP_App::getApp()->getStringSet();
+
 	UT_ASSERT(UT_pointerArrayLength((void **) m_szSuffixes) ==
 			  UT_pointerArrayLength((void **) m_szDescriptions));
 
@@ -130,15 +132,14 @@ void XAP_Win32Dialog_FileOpenSaveAs::_buildFilterList(UT_String& sFilter)
 	}
 
 	// all supported files filter
-	// TODO localize
-	sFilter += m_id == XAP_DIALOG_ID_INSERT_PICTURE ? "All AbiWord Image Files" : "All AbiWord Documents";
+	sFilter += m_id == XAP_DIALOG_ID_INSERT_PICTURE ? pSS->getValue(XAP_STRING_ID_DLG_FOSA_ALLIMAGES) : pSS->getValue(XAP_STRING_ID_DLG_FOSA_ALLDOCS);
 	sFilter += " (" + sAllSuffixes + ")";
 	sFilter += '\0';				// include the trailing 0
 	sFilter += sAllSuffixes;
 	sFilter += '\0';				// include the trailing 0
 
 	// all files filter
-	sFilter += "All (*.*)";
+	sFilter += pSS->getValue(XAP_STRING_ID_DLG_FOSA_ALL);
 	sFilter += '\0';				// include the trailing 0
 	sFilter += "*.*";
 	sFilter += '\0';				// include the trailing 0
@@ -265,7 +266,6 @@ void XAP_Win32Dialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		break;
 
 	case XAP_DIALOG_ID_PRINTTOFILE:
-		// TODO localize
 		ofn.lpstrTitle = pSS->getValue(XAP_STRING_ID_DLG_FOSA_PrintToFileTitle);
 		ofn.Flags |= OFN_OVERWRITEPROMPT;
 		bDialogResult = GetSaveFileName(&ofn);
@@ -279,6 +279,7 @@ void XAP_Win32Dialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		ofn.Flags |= OFN_ENABLEHOOK;
 		bDialogResult = GetSaveFileName(&ofn);
 		break;
+
 	case XAP_DIALOG_ID_INSERT_PICTURE:
 		ofn.lpstrTitle     = pSS->getValue(XAP_STRING_ID_DLG_IP_Title);
 		ofn.hInstance      = pWin32App->getInstance();
@@ -289,6 +290,22 @@ void XAP_Win32Dialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		ofn.Flags |= OFN_ENABLEHOOK;
 		bDialogResult = GetOpenFileName(&ofn);
 		break;
+
+	case XAP_DIALOG_ID_FILE_IMPORT:
+		ofn.lpstrTitle = pSS->getValue(XAP_STRING_ID_DLG_FOSA_ImportTitle);
+		ofn.Flags |= OFN_FILEMUSTEXIST;
+		bDialogResult = GetOpenFileName(&ofn);
+		break;
+
+	case XAP_DIALOG_ID_FILE_EXPORT:
+		ofn.lpstrTitle = pSS->getValue(XAP_STRING_ID_DLG_FOSA_ExportTitle);
+		ofn.lpfnHook       = (LPOFNHOOKPROC) s_hookSaveAsProc;
+		ofn.Flags |= OFN_OVERWRITEPROMPT;
+		ofn.Flags |= OFN_EXPLORER;
+		ofn.Flags |= OFN_ENABLEHOOK;
+		bDialogResult = GetSaveFileName(&ofn);
+		break;
+
 	default:
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		break;
@@ -520,7 +537,6 @@ UINT XAP_Win32Dialog_FileOpenSaveAs::_previewPicture(HWND hDlg)
 	double		scale_factor = 0.0;
 	UT_sint32	scaled_width,scaled_height;
 	UT_sint32	iImageWidth,iImageHeight;
-	UT_Byte     *pszWidth,*pszHeight;
 	RECT		r;
 
 	GetClientRect (hThumbnail, &r);
@@ -532,9 +548,12 @@ UINT XAP_Win32Dialog_FileOpenSaveAs::_previewPicture(HWND hDlg)
 	}
 	else
 	{
-		UT_SVG_getDimensions(pBB, &pszWidth, &pszHeight);
-		iImageWidth  = (UT_sint32)(*pszWidth);
-		iImageHeight = (UT_sint32)(*pszHeight);
+		UT_sint32 layoutWidth;
+		UT_sint32 layoutHeight;
+		// TODO Fix this
+	//	UT_SVG_getDimensions(pBB, pGr, iImageWidth, iImageHeight, layoutWidth, layoutHeight);
+		iImageWidth = 0;
+		iImageHeight = 0;
 	}
 
 	// Update Height and Width Strings
