@@ -87,11 +87,16 @@ dcl(DLG_UFS_Direction,     "Right-to-left")
 /* Unix FileOpenSaveAs dialog */
 dcl(DLG_FOSA_OpenTitle,					"Open File")
 dcl(DLG_FOSA_SaveAsTitle,				"Save File As")
+dcl(DLG_FOSA_ExportTitle, "Export File")
+dcl(DLG_FOSA_ImportTitle, "Import File")
 dcl(DLG_FOSA_PrintToFileTitle,			"Print To File")
 dcl(DLG_FOSA_FileOpenTypeLabel,			"Open file as type:")
 dcl(DLG_FOSA_FileSaveTypeLabel,			"Save file as type:")
 dcl(DLG_FOSA_FilePrintTypeLabel,		"Print file as type:")
-dcl(DLG_FOSA_FileTypeAutoDetect,		"Automatically Detected")	
+dcl(DLG_FOSA_FileTypeAutoDetect,		"Automatically Detected")
+dcl(DLG_FOSA_ALLIMAGES, "All Image Files")
+dcl(DLG_FOSA_ALLDOCS, "All Documents")
+dcl(DLG_FOSA_ALL, "All (*.*)")
 dcl(DLG_InvalidPathname,				"Invalid pathname.")
 dcl(DLG_NoSaveFile_DirNotExist,			"A directory in the given pathname does not exist.")
 dcl(DLG_NoSaveFile_DirNotWriteable,		"The directory '%s' is write-protected.")
