@@ -450,7 +450,7 @@ fp_Page* FL_DocLayout::addNewPage(fl_DocSectionLayout* pOwner)
 	// so that it can update the scroll bar ranges
 	// and whatever else it needs to do.
 
-	if (m_pView)
+	if (m_pView && m_pView->shouldScreenUpdateOnGeneralUpdate()) // skip this if rebuilding
 	{
 		m_pView->notifyListeners(AV_CHG_PAGECOUNT);
 	}
@@ -576,6 +576,14 @@ void FL_DocLayout::formatAll()
 	UT_ASSERT(m_pDoc);
 	m_pDoc->enableListUpdates();
 	fl_SectionLayout* pSL = m_pFirstSection;
+//  	while (pSL)
+//  	{
+//  		if(pSL->getType() == FL_SECTION_DOC)
+//  		{
+//  			static_cast<fl_DocSectionLayout *>(pSL)->collapseDocSection();
+//  		}
+//  		pSL = pSL->getNext();
+//  	}
 	while (pSL)
 	{
 		pSL->format();
@@ -584,6 +592,68 @@ void FL_DocLayout::formatAll()
 	}
 }
 
+
+void FL_DocLayout::rebuildFromHere( fl_DocSectionLayout * pFirstDSL)
+{
+	UT_ASSERT(m_pDoc);
+//
+	fl_DocSectionLayout * pStart = pFirstDSL;
+//	fl_DocSectionLayout * pStart = pFirstDSL->getPrevDocSection();
+//	if(pStart == NULL)
+//	{
+//		pStart = pFirstDSL;
+//	}
+	fl_DocSectionLayout * pDSL = pStart;
+	// add page view dimensions 
+#if 1
+	UT_DEBUGMSG(("SEVIOR: Rebuild from section %x \n",pFirstDSL));
+	for(UT_uint32 k=0; k< m_vecPages.getItemCount(); k++)
+	{
+		fp_Page * pPage = (fp_Page *) m_vecPages.getNthItem(k);
+		if(pPage->getOwningSection() == pFirstDSL)
+		{
+			UT_DEBUGMSG(("SEVIOR: Rebuilding from page %d \n",k));
+			break;
+		}
+	}
+#endif
+	deleteEmptyColumnsAndPages();
+	while (pDSL)
+	{
+		
+		pDSL->collapseDocSection();
+		pDSL = pDSL->getNextDocSection();
+	}
+//
+// Clear out rebuild marks from this collapse
+//
+	pDSL = (fl_DocSectionLayout *) m_pFirstSection;
+	while(pDSL)
+	{
+		pDSL->clearRebuild();
+		pDSL = pDSL->getNextDocSection();
+	}
+
+	deleteEmptyColumnsAndPages();
+	pDSL= pStart;
+	while (pDSL)
+	{
+		UT_DEBUGMSG(("SEVIOR: Building section %x \n",pDSL));
+		pDSL->updateDocSection();
+		pDSL->clearRebuild();
+		pDSL = pDSL->getNextDocSection();
+	}
+//
+// Clear out rebuild marks from the rebuild
+//
+	pDSL = (fl_DocSectionLayout *) m_pFirstSection;
+	while(pDSL)
+	{
+		pDSL->clearRebuild();
+		pDSL = pDSL->getNextDocSection();
+	}
+}
+
 void FL_DocLayout::updateLayout()
 {
 	/*
@@ -600,11 +670,21 @@ void FL_DocLayout::updateLayout()
 	while (pSL)
 	{
 		pSL->updateLayout();
-		
+		if(pSL->getType() == FL_SECTION_DOC)
+		{
+			if(static_cast<fl_DocSectionLayout *>(pSL)->needsRebuild())
+			{
+				break;
+			}
+		}
 		pSL = pSL->getNext();
 	}
-	
-	deleteEmptyColumnsAndPages();
+	if(pSL == NULL)
+	{
+		deleteEmptyColumnsAndPages();
+		return;
+	}
+	rebuildFromHere((fl_DocSectionLayout *) pSL);
 }
 
 
@@ -731,13 +811,13 @@ void FL_DocLayout::_toggleAutoSmartQuotes(bool bSQ)
 	UT_DEBUGMSG(("FL_DocLayout::_toggleAutoSmartQuotes(%s)\n", bSQ ? "true" : "false" ));
 }
 
-void FL_DocLayout::_backgroundCheck(UT_Timer * pTimer)
+void FL_DocLayout::_backgroundCheck(UT_Worker * pWorker)
 {
-	UT_ASSERT(pTimer);
+	UT_ASSERT(pWorker);
 
 	// this is a static callback method and does not have a 'this' pointer.
 
-	FL_DocLayout * pDocLayout = (FL_DocLayout *) pTimer->getInstanceData();
+	FL_DocLayout * pDocLayout = (FL_DocLayout *) pWorker->getInstanceData();
 	UT_ASSERT(pDocLayout);
 
 	if (!pDocLayout->m_pView)
@@ -816,7 +896,14 @@ void FL_DocLayout::_backgroundCheck(UT_Timer * pTimer)
 			}
 		}
 	}
-
+	else
+	{ 
+//
+// No blocks to spellcheck so stop the idle/timer. Otherwise we consume 100% CPU.
+//
+		pDocLayout->m_pBackgroundCheckTimer->stop();
+	}
+		
 	if (i != 0 && pDocLayout->m_bStopSpellChecking == false)
 	{
 		// restart timer unless it's not needed any more
@@ -834,16 +921,33 @@ void FL_DocLayout::queueBlockForBackgroundCheck(UT_uint32 reason, fl_BlockLayout
 	*/
 	if (!m_pBackgroundCheckTimer)
 	{
-		m_pBackgroundCheckTimer = UT_Timer::static_constructor(_backgroundCheck, this, m_pG);
-		if (m_pBackgroundCheckTimer)
-			m_pBackgroundCheckTimer->set(BACKGROUND_CHECK_MSECS);
+	    int inMode = UT_WorkerFactory::IDLE | UT_WorkerFactory::TIMER;
+	    UT_WorkerFactory::ConstructMode outMode = UT_WorkerFactory::NONE;
+
+	    m_pBackgroundCheckTimer = UT_WorkerFactory::static_constructor (_backgroundCheck, this, inMode, outMode, m_pG);
+
+	    UT_ASSERT(m_pBackgroundCheckTimer);
+	    UT_ASSERT(outMode != UT_WorkerFactory::NONE);
+
+	    if ( UT_WorkerFactory::TIMER == outMode )
+		{
+		// this is really a timer, so it's safe to static_cast it
+			static_cast<UT_Timer*>(m_pBackgroundCheckTimer)->set(BACKGROUND_CHECK_MSECS);
+		}
+#if 1
+	    m_bStopSpellChecking = false;
+	    m_pBackgroundCheckTimer->start();
+#endif
+
 	}
+#if 1 // We need this to restart the idle handler.
 	else
 	{
 		//		m_pBackgroundCheckTimer->stop();
 		m_bStopSpellChecking = false;
 		m_pBackgroundCheckTimer->start();
 	}
+#endif
 
 	if (hasBackgroundCheckReason(bgcrDebugFlash))
 	{
@@ -1291,13 +1395,13 @@ void FL_DocLayout::recheckIgnoredWords()
 	}
 }
 
-void FL_DocLayout::_redrawUpdate(UT_Timer * pTimer)
+void FL_DocLayout::_redrawUpdate(UT_Worker * pWorker)
 {
-	UT_ASSERT(pTimer);
+	UT_ASSERT(pWorker);
 
 	// this is a static callback method and does not have a 'this' pointer.
 
-	FL_DocLayout * pDocLayout = (FL_DocLayout *) pTimer->getInstanceData();
+	FL_DocLayout * pDocLayout = (FL_DocLayout *) pWorker->getInstanceData();
 	UT_ASSERT(pDocLayout);
 
 	if (!pDocLayout->m_pView)
@@ -1338,9 +1442,9 @@ void FL_DocLayout::_redrawUpdate(UT_Timer * pTimer)
 		pDoc->setRedrawHappenning(false);
 		return;
 	}
-
+	bool bStopOnRebuild = false;
 	fl_SectionLayout* pSL = pDocLayout->m_pFirstSection;
-	while (pSL)
+	while (pSL && !bStopOnRebuild)
 	{
 		if(pDoc->isPieceTableChanging())
 		{
@@ -1348,10 +1452,27 @@ void FL_DocLayout::_redrawUpdate(UT_Timer * pTimer)
 			return;
 		}
 		pSL->redrawUpdate();
-		pSL = pSL->getNext();
+//
+// Might need some code here to check if we need a rebuild. In principle we should not need it.
+//
+		if(pSL->getType() == FL_SECTION_DOC)
+		{
+			if(static_cast<fl_DocSectionLayout *>(pSL)->needsRebuild())
+			{
+				bStopOnRebuild = true;
+			}
+		}
+		if(!bStopOnRebuild)
+		{
+			pSL = pSL->getNext();
+		}
 	}
-
 	pDocLayout->deleteEmptyColumnsAndPages();
+	if(bStopOnRebuild)
+	{
+		UT_DEBUGMSG(("SEVIOR: Rebuilding from docLayout \n"));
+		pDocLayout->rebuildFromHere((fl_DocSectionLayout *) pSL);
+	}
 //
 // we've finished
 //
