@@ -38,6 +38,7 @@ class PP_AttrProp;
 class GR_Graphics;
 class GR_Font;
 class UT_Timer;
+class UT_Worker;
 class fl_PartOfBlock;
 class fl_AutoNum;
 
@@ -120,6 +121,7 @@ public:
 
 	void		formatAll();
 	void  		updateLayout();
+	void        rebuildFromHere(fl_DocSectionLayout * pDSL);
 	void        updateColor();
 
 	bool		isPendingWordForSpell(void) const;
@@ -186,7 +188,7 @@ public:
 #endif
 	
 protected:
-	static void			_backgroundCheck(UT_Timer * pTimer);
+	static void			_backgroundCheck(UT_Worker * pTimer);
 	void				_toggleAutoSpell(bool bSpell);
 	void				_toggleAutoSmartQuotes(bool bSQ);
 	
@@ -194,7 +196,7 @@ protected:
 									   class UT_StringPtrMap *, void *);
 
 
-	static void			_redrawUpdate(UT_Timer * pTimer);
+	static void			_redrawUpdate(UT_Worker * pTimer);
 
 	GR_Graphics*		m_pG;
 	PD_Document*		m_pDoc;
@@ -222,7 +224,7 @@ protected:
 	fl_BlockLayout*		m_pPendingBlockForSmartQuote;  // if NULL, ignore m_uOffsetForSmartQuote
 	UT_uint32           m_uOffsetForSmartQuote;
 	char                m_szCurrentTransparentColor[10];
-	UT_Timer*			m_pBackgroundCheckTimer; 
+	UT_Worker*			m_pBackgroundCheckTimer; 
 
 	XAP_Prefs *			m_pPrefs;
 
