@@ -84,7 +84,7 @@ public:
 	
 	FL_DocLayout*		getDocLayout(void) const;
 
-	virtual fp_Container*		getNewContainer() = 0;
+	virtual fp_Container*		getNewContainer(fp_Line * pFirstLine = NULL) = 0;
 	virtual fp_Container*		getFirstContainer() = 0;
 	virtual fp_Container*		getLastContainer() = 0;
 
@@ -94,6 +94,7 @@ public:
 	virtual void		format(void) = 0;
 	virtual void		updateLayout(void) = 0;
 	void                updateBackgroundColor(void);
+	void                markAllRunsDirty(void);
 
 	virtual void		redrawUpdate(void) = 0;
 
@@ -181,11 +182,13 @@ public:
 	virtual void		updateLayout(void);
 	void                updateDocSection(void);
 	void                collapseDocSection(void);
-	UT_sint32			breakSection(void);
+	UT_sint32			breakSection(fl_BlockLayout * pLastValidBlock=NULL);
+	void                markAllRunsDirty(void);
 
 	virtual void		redrawUpdate(void);
 	
-	virtual fp_Container*		getNewContainer();
+	virtual fp_Container*		getNewContainer(fp_Line * pFirstLine = NULL);
+
 	virtual fp_Container*		getFirstContainer();
 	virtual fp_Container*		getLastContainer();
 
@@ -203,11 +206,15 @@ public:
 	inline UT_sint32			getHeaderMarginInLayoutUnits(void) const { return m_iHeaderMarginLayoutUnits; }
 	inline UT_sint32			getSpaceAfter(void) const { return m_iSpaceAfter; }
 	inline UT_sint32			getSpaceAfterInLayoutUnits(void) const { return m_iSpaceAfterLayoutUnits; }
-	
+	inline UT_sint32            getMaxSectionColumnHeightInLayoutUnits(void) const { return m_iMaxSectionColumnHeightInLayoutUnits;}
+	inline UT_sint32            getMaxSectionColumnHeight(void) const { return m_iMaxSectionColumnHeight;}
 	UT_uint32			getNumColumns(void) const;
 	UT_uint32			getColumnGap(void) const;
 	UT_uint32			getColumnGapInLayoutUnits(void) const;
 	bool				getColumnLineBetween(void) const {return m_bColumnLineBetween;}
+#ifdef BIDI_ENABLED	
+	UT_uint32			getColumnOrder(void) const;
+#endif
 	void                setPaperColor();
 	UT_RGBColor *       getPaperColor(void);
 	void				deleteEmptyColumns(void);
@@ -229,7 +236,9 @@ public:
 	void                            prependOwnedHeaderPage(fp_Page * p_Page);
 	void                            prependOwnedFooterPage(fp_Page * p_Page);
 	void				deleteOwnedPage(fp_Page*);
-
+	void                markForRebuild(void) { m_bNeedsRebuild = true;}
+	void                clearRebuild(void) { m_bNeedsRebuild = false;}
+	bool                needsRebuild(void) const { return m_bNeedsRebuild;}
 	void				checkAndAdjustColumnGap(UT_sint32 iLayoutWidth);
     void                markForReformat(void) { m_bNeedsFormat = true;}
     bool                needsReFormat(void) const { return m_bNeedsFormat;}
@@ -246,6 +255,9 @@ protected:
 	UT_uint32			m_iColumnGap;
 	UT_uint32			m_iColumnGapLayoutUnits;
 	bool				m_bColumnLineBetween;
+#ifdef BIDI_ENABLED
+	UT_uint32			m_iColumnOrder;
+#endif
 
 	UT_sint32			m_iSpaceAfter;
 	UT_sint32			m_iSpaceAfterLayoutUnits;
@@ -267,6 +279,9 @@ protected:
 	UT_sint32			m_iHeaderMargin;
 	UT_sint32			m_iHeaderMarginLayoutUnits;
 	double				m_dHeaderMarginUserUnits;
+	UT_sint32           m_iMaxSectionColumnHeightInLayoutUnits;
+	UT_sint32           m_iMaxSectionColumnHeight;
+	double              m_dMaxSectionColumnHeight;
 
 	bool				m_bForceNewPage;
 
@@ -283,6 +298,7 @@ private:
 	//! For an endnote DocSectionLayout, the DSL containing it.
 	fl_DocSectionLayout* m_pEndnoteOwnerSL;
 	bool                m_bNeedsFormat;
+	bool                m_bNeedsRebuild;
 };
 
 class fl_HdrFtrSectionLayout : public fl_SectionLayout
@@ -301,6 +317,7 @@ public:
 	bool                        doclistener_deleteStrux(const PX_ChangeRecord_Strux * pcrx);
 	void                        localFormat(void);
 	void                        localCollapse(void);
+	void                        markAllRunsDirty(void);
 	void                        collapseBlock(fl_BlockLayout * pBlock);
 	virtual void				format(void);
 	virtual void				updateLayout(void);
@@ -309,7 +326,7 @@ public:
 	virtual void				redrawUpdate(void);
 	void                        updateBackgroundColor(void);
 	
-	virtual fp_Container*		getNewContainer();
+	virtual fp_Container*		getNewContainer(fp_Line * pFirstLine = NULL);
 	virtual fp_Container*		getFirstContainer();
 	virtual fp_Container*		getLastContainer();
 	fl_HdrFtrShadow *               getFirstShadow(void);
@@ -377,7 +394,7 @@ public:
 	void						clearScreen(void);
 	virtual void				redrawUpdate(void);
 	fp_Page *                       getPage(void) { return m_pPage;}
-	virtual fp_Container*		getNewContainer();
+	virtual fp_Container*		getNewContainer(fp_Line *pFirstLine = NULL);
 	virtual fp_Container*		getFirstContainer();
 	virtual fp_Container*		getLastContainer();
 	virtual bool				doclistener_changeStrux(const PX_ChangeRecord_StruxChange * pcrxc);
