@@ -109,7 +109,8 @@ fp_Run::fp_Run(fl_BlockLayout* pBL,
 	getPageColor();
 	
 #ifdef BIDI_ENABLED
-	m_iDirection = -1; //by default all runs are whitespace
+	m_iDirection = FRIBIDI_TYPE_WS; //by default all runs are whitespace
+	m_iVisDirection = FRIBIDI_TYPE_UNSET;
 #endif
 }
 
@@ -891,7 +892,7 @@ void fp_TabRun::lookupProperties(void)
 	    m_iHeightLayoutUnits = m_pG->getFontHeight(pFont);
 	}
 #ifdef BIDI_ENABLED
-	m_iDirection = -1;
+	m_iDirection = FRIBIDI_TYPE_WS;
 #endif
 //
 // Lookup Decoration properties for this run
@@ -991,7 +992,7 @@ void fp_TabRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y, U
 	
 	UT_sint32 iDirection = getVisDirection();
 
-	if(iDirection == 1)
+	if(iDirection == FRIBIDI_TYPE_RTL)
 	    x = xoff - 1;      //necessary to draw the the caret properly -- I am not sure why though #TF
 	else
 	    x = xoff + getWidth() + 1;
@@ -999,7 +1000,7 @@ void fp_TabRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y, U
 	
 	if(pRun && (iNextDir != iDirection)) //if this run precedes run of different direction, we have to split the caret
 	{
-	    x2 = (iNextDir == 0) ?  xoff + pRun->getWidth() + 1 : xoff2 - 1;
+	    x2 = (iNextDir == FRIBIDI_TYPE_LTR) ?  xoff + pRun->getWidth() + 1 : xoff2 - 1;
 	    y2 = yoff2;
 	}
 	else
@@ -1007,7 +1008,7 @@ void fp_TabRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y, U
 	    x2 = x;
 	    y2 = yoff;
 	}
-	bDirection = (iDirection != 0);
+	bDirection = (iDirection != FRIBIDI_TYPE_LTR);
 #else
 	if (iOffset == m_iOffsetFirst)
 	{
@@ -1081,6 +1082,53 @@ void fp_TabRun::_drawArrow(UT_uint32 iLeft,UT_uint32 iTop,UT_uint32 iWidth, UT_u
     UT_uint32 iMaxWidth = UT_MIN(iWidth / 10 * 6, (UT_uint32) cur_linewidth * 9);
     UT_uint32 ixGap = (iWidth - iMaxWidth) / 2;
 
+#ifdef BIDI_ENABLED
+    UT_uint32 iLeftAdj = iLeft;
+
+	if(m_iVisDirection == FRIBIDI_TYPE_LTR)
+	{
+	    points[0].x = /*iLeft*/iLeftAdj + ixGap + iMaxWidth - cur_linewidth * 4;
+    	points[0].y = iyAxis - cur_linewidth * 2;
+
+	    points[1].x = points[0].x + cur_linewidth;
+	    points[1].y = points[0].y;
+
+	    points[2].x = /*iLeft*/iLeftAdj + iWidth - ixGap;
+	    points[2].y = iyAxis;
+	}
+	else
+	{
+		//iLeftAdj -= m_iWidth;
+	
+	    points[0].x = /*iLeft*/iLeftAdj - ixGap - iMaxWidth + cur_linewidth * 4;
+    	points[0].y = iyAxis - cur_linewidth * 2;
+
+	    points[1].x = points[0].x - cur_linewidth;
+	    points[1].y = points[0].y;
+
+	    points[2].x = /*iLeft*/iLeftAdj - iWidth + ixGap;
+	    points[2].y = iyAxis;
+
+	}
+	
+    points[3].x = points[1].x;
+    points[3].y = iyAxis + cur_linewidth * 2;
+
+    points[4].x = points[0].x;
+    points[4].y = points[3].y;
+
+    points[5].x = points[0].x;
+    points[5].y = points[0].y;
+
+    UT_RGBColor clrShowPara(127,127,127);
+    m_pG->polygon(clrShowPara,points,NPOINTS);
+
+    if(m_iVisDirection == FRIBIDI_TYPE_LTR)
+	    m_pG->fillRect(clrShowPara,/*iLeft*/iLeftAdj + ixGap,iyAxis - cur_linewidth / 2,iMaxWidth - cur_linewidth * 4,cur_linewidth);
+	else
+	    m_pG->fillRect(clrShowPara,/*iLeft*/iLeftAdj - ixGap - iMaxWidth + cur_linewidth * 4,iyAxis - cur_linewidth / 2,iMaxWidth - cur_linewidth * 4,cur_linewidth);
+
+#else
     points[0].x = iLeft + ixGap + iMaxWidth - cur_linewidth * 4;
     points[0].y = iyAxis - cur_linewidth * 2;
 
@@ -1102,6 +1150,7 @@ void fp_TabRun::_drawArrow(UT_uint32 iLeft,UT_uint32 iTop,UT_uint32 iWidth, UT_u
     UT_RGBColor clrShowPara(127,127,127);
     m_pG->polygon(clrShowPara,points,NPOINTS);
     m_pG->fillRect(clrShowPara,iLeft + ixGap,iyAxis - cur_linewidth / 2,iMaxWidth - cur_linewidth * 4,cur_linewidth);
+#endif
 }
 
 void fp_TabRun::_draw(dg_DrawArgs* pDA)
@@ -1111,7 +1160,8 @@ void fp_TabRun::_draw(dg_DrawArgs* pDA)
 	UT_RGBColor clrSelBackground(192, 192, 192);
 	UT_RGBColor clrNormalBackground(m_colorHL.m_red,m_colorHL.m_grn,m_colorHL.m_blu);
 	// need to draw to the full height of line to join with line above.
-	UT_sint32 xoff= 0, yoff=0;
+	UT_sint32 xoff= 0, yoff=0, DA_xoff = pDA->xoff;
+	
 	getLine()->getScreenOffsets(this, xoff, yoff);
 
 	UT_sint32 iFillHeight = m_pLine->getHeight();
@@ -1128,6 +1178,11 @@ void fp_TabRun::_draw(dg_DrawArgs* pDA)
 	
 #ifdef BIDI_ENABLED
 	UT_uint32 iRunBase = m_pBL->getPosition() + getOffsetFirstVis(); //m_iOffsetFirst;
+	if(getVisDirection() == FRIBIDI_TYPE_RTL)
+	{
+		DA_xoff -= m_iWidth;
+		xoff -= m_iWidth;
+	}	
 #else
 	UT_uint32 iRunBase = m_pBL->getPosition() + m_iOffsetFirst;
 #endif
@@ -1182,7 +1237,7 @@ void fp_TabRun::_draw(dg_DrawArgs* pDA)
 
 		i = (i>=3) ? i - 2 : 1;
 		m_pG->setColor(clrFG);
-		m_pG->drawChars(tmp, 1, i, pDA->xoff, iFillTop);
+		m_pG->drawChars(tmp, 1, i, /*pDA->xoff*/DA_xoff, iFillTop);
 	}
 	else
 	if (
@@ -1191,16 +1246,16 @@ void fp_TabRun::_draw(dg_DrawArgs* pDA)
 		&& (iSel2 > iRunBase)
 		)
 	{
-		m_pG->fillRect(clrSelBackground, pDA->xoff, iFillTop, m_iWidth, iFillHeight);
+		m_pG->fillRect(clrSelBackground, /*pDA->xoff*/DA_xoff, iFillTop, m_iWidth, iFillHeight);
         if(pView->getShowPara()){
-            _drawArrow(pDA->xoff, iFillTop, m_iWidth, iFillHeight);
+            _drawArrow(/*pDA->xoff*/DA_xoff, iFillTop, m_iWidth, iFillHeight);
         }
 	}
 	else
 	{
-		m_pG->fillRect(clrNormalBackground, pDA->xoff, iFillTop, m_iWidth, iFillHeight);
+		m_pG->fillRect(clrNormalBackground, /*pDA->xoff*/DA_xoff, iFillTop, m_iWidth, iFillHeight);
         if(pView->getShowPara()){
-            _drawArrow(pDA->xoff, iFillTop, m_iWidth, iFillHeight);
+            _drawArrow(/*pDA->xoff*/DA_xoff, iFillTop, m_iWidth, iFillHeight);
         }
 	}
 //
@@ -1220,7 +1275,7 @@ void fp_TabRun::_draw(dg_DrawArgs* pDA)
 // Scale the vertical line thickness for printers
 //
 		UT_sint32 ithick =  getToplineThickness();
-		m_pG->fillRect(clrFG, pDA->xoff+getWidth()-ithick, iFillTop, ithick, iFillHeight);
+		m_pG->fillRect(clrFG, /*pDA->xoff*/DA_xoff+getWidth()-ithick, iFillTop, ithick, iFillHeight);
 	}
 }
 
@@ -1438,6 +1493,7 @@ fp_EndOfParagraphRun::fp_EndOfParagraphRun(fl_BlockLayout* pBL,
 	
 	m_iLen = 1;
 	m_bDirty = true;
+	m_iWidth = 0;
 #ifdef BIDI_ENABLED
 	UT_ASSERT((pBL));
 	m_iDirection = pBL->getDominantDirection();
@@ -1477,7 +1533,7 @@ void fp_EndOfParagraphRun::lookupProperties(void)
 											   FL_DocLayout::FIND_FONT_AT_SCREEN_RESOLUTION);
 			m_pG->setFont(pFont);
 		}
-		m_iWidth  = m_pG->measureString(pEOP, 0, iTextLen, NULL);
+		m_iDrawWidth  = m_pG->measureString(pEOP, 0, iTextLen, NULL);
 		xxx_UT_DEBUGMSG(("fp_EndOfParagraphRun::lookupProperties: width %d\n", m_iWidth));
 	}
 	else
@@ -1486,7 +1542,13 @@ void fp_EndOfParagraphRun::lookupProperties(void)
 		// document to the right of the pilcrow, see Paul's suggested
 		// selection behaviors. Doesn't matter until we get selection
 		// support though (which requires PT changes).
-		m_iWidth = 8;
+		
+		// I have changed this to 0, because otherwise it figures in
+		// calculation of line width, and the last line in righ-aligned
+		// paragraphs is shifted by the width of the pilcrow.
+		// this required some additional changes to the _draw function
+		// Tomas
+		m_iDrawWidth = 0;
 	}
 }
 
@@ -1560,11 +1622,17 @@ void fp_EndOfParagraphRun::_clearScreen(bool /* bFullLineHeightRect */)
 	UT_ASSERT(!m_bDirty);
 	UT_ASSERT(m_pG->queryProperties(GR_Graphics::DGP_SCREEN));
 
-	FV_View* pView = m_pBL->getDocLayout()->getView();
-		
 	UT_sint32 xoff = 0, yoff = 0;
 	m_pLine->getScreenOffsets(this, xoff, yoff);
-	m_pG->fillRect(m_colorPG, xoff, yoff, m_iWidth, m_pLine->getHeight());
+	
+#ifdef BIDI_ENABLED
+	if(m_pBL->getDominantDirection() == FRIBIDI_TYPE_RTL)
+	{
+		xoff -= m_iDrawWidth;
+	}
+#endif
+	
+	m_pG->fillRect(m_colorPG, xoff, yoff, m_iDrawWidth, m_pLine->getHeight());
 }
 
 /*!
@@ -1579,11 +1647,25 @@ void fp_EndOfParagraphRun::_clearScreen(bool /* bFullLineHeightRect */)
 */
 void fp_EndOfParagraphRun::_draw(dg_DrawArgs* pDA)
 {
+	// if showPara is turned off we will not draw anything at all; however,
+	// we will ensure that the width is set to 0, and if it is currently not
+	// we will get our line to redo its layout and redraw.
+	FV_View* pView = m_pBL->getDocLayout()->getView();
+    if(!pView || !pView->getShowPara())
+    {
+    	if(m_iDrawWidth)
+    	{
+    		m_iDrawWidth = 0;
+    		//m_pLine->layout();
+    		//m_pLine->redrawUpdate();
+    	}
+    	return;
+    }
+    	
 	UT_ASSERT(pDA->pG == m_pG);
 
 	UT_uint32 iRunBase = m_pBL->getPosition() + m_iOffsetFirst;
 
-	FV_View* pView = m_pBL->getDocLayout()->getView();
 	UT_uint32 iSelAnchor = pView->getSelectionAnchor();
 	UT_uint32 iPoint = pView->getPoint();
 
@@ -1630,21 +1712,43 @@ void fp_EndOfParagraphRun::_draw(dg_DrawArgs* pDA)
 		m_pG->setFont(pFont);
 		iAscent = m_pG->getFontAscent();
 	}
+	
+	// if we currently have a 0 width, i.e., we draw in response to the
+	// showPara being turned on, then we obtain the new width, and then
+	// tell the line to redo its layout and redraw instead of drawing ourselves
+//	bool bWidthChange = false;
+//	if(!m_iDrawWidth)
+//		bWidthChange = true;
 
-	m_iWidth  = m_pG->measureString(pEOP, 0, iTextLen, NULL);
+	m_iDrawWidth  = m_pG->measureString(pEOP, 0, iTextLen, NULL);
+// 	if(bWidthChange)
+//	{
+//		m_pLine->layout();
+//		m_pLine->redrawUpdate();
+//		return;
+//	}
+	
 	m_iHeight = m_pG->getFontHeight();
 	m_iXoffText = pDA->xoff;
-	m_iYoffText = pDA->yoff - iAscent; 
-	xxx_UT_DEBUGMSG(("fp_EndOfParagraphRun::draw: width %d\n", m_iWidth));
+
+#ifdef BIDI_ENABLED
+	if(m_pBL->getDominantDirection() == FRIBIDI_TYPE_RTL)
+	{
+		m_iXoffText -= m_iDrawWidth;
+	}
+#endif
+		
+	m_iYoffText = pDA->yoff - iAscent;
+	xxx_UT_DEBUGMSG(("fp_EndOfParagraphRun::draw: width %d\n", m_iDrawWidth));
 
 	if (bIsSelected)
 	{
-		m_pG->fillRect(clrSelBackground, m_iXoffText, m_iYoffText, m_iWidth, m_pLine->getHeight());
+		m_pG->fillRect(clrSelBackground, m_iXoffText, m_iYoffText, m_iDrawWidth, m_pLine->getHeight());
 		UT_setColor(clrShowPara, 80, 80, 80);
 	}
 	else
 	{
-		m_pG->fillRect(m_colorPG, m_iXoffText, m_iYoffText, m_iWidth, m_pLine->getHeight());
+		m_pG->fillRect(m_colorPG, m_iXoffText, m_iYoffText, m_iDrawWidth, m_pLine->getHeight());
 	}
 	if (pView->getShowPara())
 	{
@@ -1785,7 +1889,7 @@ void fp_ImageRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 	height = m_iHeight;
 #ifdef BIDI_ENABLED
 	y2 = y;
-	bDirection = (getVisDirection() != 0);
+	bDirection = (getVisDirection() != FRIBIDI_TYPE_LTR);
 #endif
 }
 
@@ -1931,6 +2035,27 @@ fp_FieldRun::fp_FieldRun(fl_BlockLayout* pBL, GR_Graphics* pG, UT_uint32 iOffset
 	m_sFieldValue[0] = 0;
 }
 
+bool fp_FieldRun::recalcWidth()
+{
+	unsigned short aCharWidths[FPFIELD_MAX_LENGTH];
+	lookupProperties();
+	m_pG->setFont(m_pFont);
+	UT_sint32 iNewWidth = m_pG->measureString(m_sFieldValue, 0, UT_UCS_strlen(m_sFieldValue), aCharWidths);
+	xxx_UT_DEBUGMSG(("fp_FieldRun::recalcWidth: old width %d, new width %d\n", m_iWidth, iNewWidth));
+	if (iNewWidth != m_iWidth)
+	{
+		clearScreen();
+		m_iWidth = iNewWidth;
+
+		m_pG->setFont(m_pFontLayout);
+		m_iWidthLayoutUnits = m_pG->measureString(m_sFieldValue, 0, UT_UCS_strlen(m_sFieldValue), aCharWidths);
+
+		return true;
+	}
+
+	return false;
+}
+
 bool fp_FieldRun::_setValue(UT_UCSChar *p_new_value)
 {
 
@@ -2050,11 +2175,11 @@ void fp_FieldRun::lookupProperties(void)
 	const XML_Char * pszDirection = PP_evalProperty("dir",pSpanAP,pBlockAP,pSectionAP, pDoc, true);
 	if(!UT_stricmp(pszDirection, "rtl"))
 	{
-		m_iDirection = 1;
+		m_iDirection = FRIBIDI_TYPE_R;
 	}
 	else
 	{
-		m_iDirection = 0;
+		m_iDirection = FRIBIDI_TYPE_L;
 	}
 #endif
 
@@ -2190,7 +2315,7 @@ void fp_FieldRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x,
 #ifdef BIDI_ENABLED
 	x2 = x;
 	y2 = y;
-	bDirection = (getVisDirection() != 0);
+	bDirection = (getVisDirection() != FRIBIDI_TYPE_LTR);
 #endif
 }
 
@@ -3369,7 +3494,7 @@ void fp_ForcedPageBreakRun::_draw(dg_DrawArgs* pDA)
 // (will also translate correctly visual -> logical)
 UT_uint32 fp_Run::getVisPosition(UT_uint32 iLogPos)
 {
-    if(getVisDirection() == 1) //rtl needs translation
+    if(getVisDirection() == FRIBIDI_TYPE_RTL) //rtl needs translation
     {
         return (m_iLen - iLogPos - 1);
     }
@@ -3380,7 +3505,7 @@ UT_uint32 fp_Run::getVisPosition(UT_uint32 iLogPos)
 //or vice versa
 UT_uint32 fp_Run::getVisPosition(UT_uint32 iLogPos, UT_uint32 iLen)
 {
-    if(getVisDirection() == 1) //rtl needs translation
+    if(getVisDirection() == FRIBIDI_TYPE_RTL) //rtl needs translation
     {
         return (iLen - iLogPos - 1);
     }
@@ -3390,7 +3515,7 @@ UT_uint32 fp_Run::getVisPosition(UT_uint32 iLogPos, UT_uint32 iLen)
 //returns the logical offset of the first visual character
 UT_uint32 fp_Run::getOffsetFirstVis()
 {
-    if(getVisDirection() == 1) //rtl, requires translation
+    if(getVisDirection() == FRIBIDI_TYPE_RTL) //rtl, requires translation
     {
         return(m_iOffsetFirst + m_iLen - 1);
     }
@@ -3401,23 +3526,20 @@ UT_uint32 fp_Run::getOffsetFirstVis()
 //in the other direction
 UT_uint32 fp_Run::getOffsetLog(UT_uint32 iVisOff)
 {
-    if(getVisDirection() == 1) //rtl needs translation
+    if(getVisDirection() == FRIBIDI_TYPE_RTL) //rtl needs translation
     {
         return(m_iOffsetFirst + m_iLen - iVisOff + m_iOffsetFirst - 1);
     }
     else return (iVisOff);
 }
 
-void fp_Run::setDirection(UT_sint32 iDir)
+void fp_Run::setDirection(FriBidiCharType iDir)
 {
-	//this function should be called with -1,0,1; if it is called
-	//with -2, which is used in the derived classes that can handle
-	//Unicode as an indication that direction should be worked out
-	//from Unicode, we will treat this a whitespace
-
-	UT_sint32 iDirection = iDir != -2 ? iDir : -1;
+    xxx_UT_DEBUGMSG(("fp_Run::SetDirection, m_iDirection %d, iDir %d, run type %d\n", m_iDirection, iDir, getType()));
+	FriBidiCharType iDirection = iDir != FRIBIDI_TYPE_UNSET ? iDir : FRIBIDI_TYPE_WS;
 	if(m_iDirection != iDirection)
 	{
+		FriBidiCharType origDirection = m_iDirection;
 		m_iDirection = iDirection;
 		clearScreen();
 		/*
@@ -3430,95 +3552,38 @@ void fp_Run::setDirection(UT_sint32 iDir)
 		*/
 	
 		if(m_pLine)
-			m_pLine->addDirectionUsed(m_iDirection);
-
+			m_pLine->changeDirectionUsed(origDirection,m_iDirection,true);
 	}
 }
 
-// returns the direction with which the run is displayed, converting the direction of white
-// space to either ltr or rtl depending on context
-UT_sint32 fp_Run::getVisDirection()
+// returns the direction with which the run is displayed,
+FriBidiCharType fp_Run::getVisDirection()
 {
-    if(m_iDirection == 2) //direction not set, yet, use dominant direction;
-    {
-        return (m_pBL->getDominantDirection());
-    }
-
-    if(m_iDirection != -1)
-    {
-        //UT_DEBUGMSG(("getVisDirection (non-white): direction = %d, visDirection = %d\n", m_iDirection, m_iDirection));
-        return(m_iDirection);
-    }
-
-    UT_sint32 iBlDirection = (UT_sint32) m_pBL->getDominantDirection();
-    fp_Run * r = getPrev();
-    UT_sint32 prevDir;
-
-    // find first non-white run before this one
-    while (r)
-    {
-        prevDir = r->getDirection();
-        r = r->getPrev();
-
-        if(prevDir == iBlDirection)
-        {
-            //UT_DEBUGMSG(("getVisDirection (prev): direction = %d, visDirection = %d\n", m_iDirection, iBlDirection));
-            return(iBlDirection);
-        }
-        if(prevDir != -1) break; //run of foreign direction
-    }
-
-    // if there are no non-white runs, return direction of the block
-    if(r == 0)
-    {
-        //UT_DEBUGMSG(("getVisDirection (non-white start): direction = %d, visDirection = %d\n", m_iDirection, iBlDirection));
-        return(iBlDirection);
-    }
-
-    // now we know that the preceding run is of foreing direction, in which case
-    // the direction of white space depends on the first non-white run that follows it
-    UT_sint32 nextDir;
-    r = getNext();
-
-    while(r)
-    {
-        nextDir = r->getDirection();
-
-        if(nextDir != -1)
-        {
-            //UT_DEBUGMSG(("getVisDirection (next): direction = %d, visDirection = %d\n", m_iDirection, nextDir));
-            //last run pefore end of paragraph mark will have direction of the run
-            //that precedes it, otherwise the direction of the next run
-            return(r->getType() == FPRUN_ENDOFPARAGRAPH) ? prevDir : nextDir;
-        }
-        r = r->getNext();
-
-    }
-
-    // if get this far, this white space run is the last one on the line
-    // and will have the direciton of the previous run
-    //UT_DEBUGMSG(("getVisDirection (last on line): direction = %d, visDirection = %d\n", m_iDirection, prevDir));
-    return(prevDir);
+	if(m_iVisDirection == FRIBIDI_TYPE_UNSET)
+	{
+		if(m_pBL)
+			return m_pBL->getDominantDirection();
+		else
+		{
+			bool b;	
+			XAP_App::getApp()->getPrefsValueBool((XML_Char*)AP_PREF_KEY_DefaultDirectionRtl, &b);
+			if(b)
+				return FRIBIDI_TYPE_RTL;
+			else
+				return FRIBIDI_TYPE_LTR;
+		}
+	}
+	else
+		return m_iVisDirection;
 }
 
-/*
-bool fp_Run::setUnicodeDirection()
+void fp_Run::setVisDirection(FriBidiCharType iDir)
 {
-	//bool bSetProperty = (m_iDirection == 2) ? true : false; //do we need to call View->setCharFormat ?
-	
-	m_iDirection = -1; //all runs that rely on this implementatio will be treated as whitespace
-	
-	//if this run did not have its direction set so far we have to call View->setCharFormat
-	//if(bSetProperty)
-	//    setDirectionProperty(-1);
-	
-	return (false);
+	m_iVisDirection = iDir;
 }
-*/
-void fp_Run::setDirectionProperty(UT_sint32 dir)
+
+void fp_Run::setDirectionProperty(FriBidiCharType dir)
 {
-	//FV_View * pView = getBlock()->getDocLayout()->getView();
-	//UT_ASSERT(pView);
 	const XML_Char * prop[] = {NULL, NULL, 0};
 	const XML_Char direction[] = "dir";
 	const XML_Char rtl[] = "rtl";
@@ -3529,13 +3594,11 @@ void fp_Run::setDirectionProperty(UT_sint32 dir)
 	
 	switch(dir)
 	{
-	case 0:  prop[1] = (XML_Char*) &ltr;     break;
-	case 1:  prop[1] = (XML_Char*) &rtl;     break;
-	case -1: prop[1] = (XML_Char*) &neutral; break;
-	default: UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		case FRIBIDI_TYPE_LTR:  prop[1] = (XML_Char*) &ltr;     break;
+		case FRIBIDI_TYPE_RTL:  prop[1] = (XML_Char*) &rtl;     break;
+		default: prop[1] = (XML_Char*) &neutral; break;
 	};
 	
-	//pView->setCharFormat(prop);
 	UT_uint32 offset = m_pBL->getPosition() + m_iOffsetFirst;
 	getBlock()->getDocument()->changeSpanFmt(PTC_AddFmt,offset,offset + m_iLen,NULL,prop);
 	//UT_DEBUGMSG(("Run::setDirectionProperty: offset=%d, len=%d\n", offset,m_iLen));
