@@ -45,7 +45,7 @@
 #include "ut_Language.h"
 #ifdef BIDI_ENABLED
 //#define CAPS_TEST
-#include "AbiFriBiDi.h"
+#include "fribidi.h"
 #include "ap_Prefs.h"
 #endif
 
@@ -56,6 +56,7 @@
 UT_UCSChar * fp_TextRun::s_pSpanBuff = 0;
 UT_uint32    fp_TextRun::s_iClassInstanceCount = 0;
 UT_uint32    fp_TextRun::s_iSpanBuffSize = 0;
+UT_UCSChar getMirrorChar(UT_UCSChar c);
 #endif
 
 
@@ -74,9 +75,9 @@ fp_TextRun::fp_TextRun(fl_BlockLayout* pBL,
 	m_pField = NULL;
 	m_pLanguage = NULL;
 #ifdef BIDI_ENABLED
-	m_iDirection = 2; //we will use this as an indication that the direction property has not been yet set
+	m_iDirection = FRIBIDI_TYPE_UNSET; //we will use this as an indication that the direction property has not been yet set
 			  //normal values are -1,0,1 (neutral, ltr, rtl)
-	m_iDirOverride = -1; //no override by default
+	m_iDirOverride = FRIBIDI_TYPE_UNSET; //no override by default
 #endif
 	if (bLookupProperties)
 	{
@@ -239,42 +240,31 @@ void fp_TextRun::lookupProperties(void)
 	delete lls;
 
 #ifdef BIDI_ENABLED
-	const XML_Char * pszDirection = PP_evalProperty("dir",pSpanAP,pBlockAP,pSectionAP, pDoc, true);
+
+	const XML_Char * pszDirection; /* = PP_evalProperty("dir",pSpanAP,pBlockAP,pSectionAP, pDoc, true);
 	//UT_DEBUGMSG(( "pszDirection = %s\n", pszDirection ));
-	//UT_ASSERT((m_pLine));
-	UT_sint32 prevDir = m_iDirection;
-	if(!UT_stricmp(pszDirection, "rtl"))
-	{
-		m_iDirection = 1;
-		//m_pLine->orDirectionsUsed(FP_LINE_DIRECTION_USED_RTL);
-	}
-	else if(!UT_stricmp(pszDirection, "ltr"))
-	{
-		m_iDirection = 0;
-		//m_pLine->orDirectionsUsed(FP_LINE_DIRECTION_USED_LTR);
-	}
-	else
-	{
-		m_iDirection = -1; //whitespace
-	}
+	//UT_ASSERT((m_pLine));  */
+	
+	FriBidiCharType prevDir = m_iDirection;
+	
+	//if(m_iDirection == FRIBIDI_TYPE_UNSET)
+	//	setDirection(FRIBIDI_TYPE_UNSET);
 
 	//UT_DEBUGMSG(("TextRun: lookupProperties, m_iDirection=%d (%s)\n", m_iDirection, pszDirection));
     pszDirection = PP_evalProperty("dir-override",pSpanAP,pBlockAP,pSectionAP, pDoc, true);
     if(!UT_stricmp(pszDirection, "rtl"))
-    	m_iDirOverride = 1;
+    	m_iDirOverride = FRIBIDI_TYPE_RTL;
     else if(!UT_stricmp(pszDirection, "ltr"))
-    	m_iDirOverride = 0;
+    	m_iDirOverride = FRIBIDI_TYPE_LTR;
     else
-    	m_iDirOverride = -1;
+    	m_iDirOverride = FRIBIDI_TYPE_UNSET;
 
-    if(m_iDirOverride != -1)
+    if(m_iDirOverride != FRIBIDI_TYPE_UNSET)
     	m_iDirection = m_iDirOverride;
     	
    	if(m_iDirection != prevDir && m_pLine)
    	{
-    	m_pLine->removeDirectionUsed(prevDir);
-    	m_pLine->addDirectionUsed(m_iDirection);
-    	m_pLine->setMapOfRunsDirty();
+    	m_pLine->changeDirectionUsed(prevDir, m_iDirection, true);
     }
 	    //UT_DEBUGMSG(("TextRun::lookupProperties: m_iDirection=%d, m_iDirOverride=%d\n", m_iDirection, m_iDirOverride));
 #endif
@@ -486,19 +476,49 @@ void fp_TextRun::mapXYToPosition(UT_sint32 x, UT_sint32 /*y*/,
 {
 	if (x <= 0)
 	{
+#ifdef BIDI_ENABLED
+		if(m_pBL->getDominantDirection() == FRIBIDI_TYPE_RTL)
+		{
+			pos = m_pBL->getPosition() + m_iOffsetFirst + m_iLen;
+			bEOL = true;
+			bBOL = false;
+		}
+		else
+		{
+			pos = m_pBL->getPosition() + m_iOffsetFirst;
+			bEOL = false;
+			bBOL = true;
+		}
+#else		
 		pos = m_pBL->getPosition() + m_iOffsetFirst;
 		// don't set bBOL to false here
 		bEOL = false;
+#endif
 		return;
 	}
 
 	if (x >= m_iWidth)
 	{
+#ifdef BIDI_ENABLED
+		if(m_pBL->getDominantDirection() == FRIBIDI_TYPE_RTL)
+		{
+			pos = m_pBL->getPosition() + m_iOffsetFirst;
+			bEOL = false;
+			bBOL = true;
+		}
+		else
+		{
+			pos = m_pBL->getPosition() + m_iOffsetFirst + m_iLen;
+			bEOL = true;
+			bBOL = false;
+		}
+#else
 		pos = m_pBL->getPosition() + m_iOffsetFirst + m_iLen;
 		// Setting bEOL fixes bug 1149. But bEOL has been set in the
 		// past - probably somewhere else, so this is not necessarily
 		// the correct place to do it.  2001.02.25 jskov
 		bEOL = true;
+#endif
 		return;
 	}
 
@@ -583,7 +603,7 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 	}
 #ifdef BIDI_ENABLED
 	UT_sint32 iDirection = getVisDirection();
-	UT_sint32 iNextDir = iDirection ? 0 : 1; //if this is last run we will anticipate the next to have *different* direction
+	UT_sint32 iNextDir = iDirection == FRIBIDI_TYPE_RTL ? FRIBIDI_TYPE_LTR : FRIBIDI_TYPE_RTL; //if this is last run we will anticipate the next to have *different* direction
 	fp_Run * pRun = 0;   //will use 0 as indicator that there is no need to deal with the second caret
 #ifdef UT_DEBUG	
 	UT_uint32 rtype;
@@ -607,7 +627,7 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 	    }
 	}
 
-	if(iDirection == 1)                 //#TF rtl run
+	if(iDirection == FRIBIDI_TYPE_RTL)                 //#TF rtl run
 	{
 	    x = xoff + m_iWidth - xdiff; //we want the caret right of the char
 	}
@@ -618,7 +638,7 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 	
     if(pRun && (iNextDir != iDirection)) //followed by run of different direction, have to split caret
 	{
-		x2 = (iNextDir == 0) ? xoff2 : xoff2 + pRun->getWidth();
+		x2 = (iNextDir == FRIBIDI_TYPE_LTR) ? xoff2 : xoff2 + pRun->getWidth();
 		y2 = yoff2;
 	}
 	else
@@ -626,7 +646,7 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 	    x2 = x;
 	    y2 = yoff;
 	}
-	bDirection = (iDirection != 0);
+	bDirection = (iDirection != FRIBIDI_TYPE_LTR);
 #else	    // ! BIDI_ENABLED
 	x = xoff;
 #endif
@@ -753,7 +773,7 @@ bool fp_TextRun::split(UT_uint32 iSplitOffset)
 #ifdef BIDI_ENABLED
 	//bool bDomDirection = m_pBL->getDominantDirection();
 	
-	if(getVisDirection() == 0)
+	if(getVisDirection() == FRIBIDI_TYPE_LTR)
 	{
 		pNew->m_iX = m_iX + m_iWidth;
 	}
@@ -895,7 +915,7 @@ UT_sint32 fp_TextRun::simpleRecalcWidth(UT_sint32 iWidthType, UT_sint32 iLength)
 			}
 		}
 	}
-
+ 	//UT_DEBUGMSG(("fp_TextRun (0x%x)::simpleRecalcWidth: width %d\n", this, iWidth));
 	return iWidth;
 }
 
@@ -978,6 +998,7 @@ void fp_TextRun::_clearScreen(bool /* bFullLineHeightRect */)
 			if(bthis && pPrev->getType() == FPRUN_IMAGE)
 				leftClear = 0;
 		}
+		UT_DEBUGMSG(("SEVIOR: leftclear in textrun = %d \n",leftClear));
 		m_pG->fillRect(clrNormalBackground,xoff-leftClear , yoff, m_iWidth+leftClear, m_pLine->getHeight());
 	}
 
@@ -1186,7 +1207,7 @@ void fp_TextRun::_getPartRect(UT_Rect* pRect,
 	}
 	
 #ifdef BIDI_ENABLED
-	if(getVisDirection() == 0)
+	if(getVisDirection() == FRIBIDI_TYPE_LTR)
 	{
 		pRect->left += xoff; //if this is ltr then adding xoff is all that is needed
 	}
@@ -1197,7 +1218,7 @@ void fp_TextRun::_getPartRect(UT_Rect* pRect,
 	}
 #ifdef BIDI_ENABLED
 	//in case of rtl we are now in the position to calculate the position of the the left corner
-	if(getVisDirection() == 1) pRect->left = xoff + m_iWidth - pRect->left - pRect->width;
+	if(getVisDirection() == FRIBIDI_TYPE_RTL) pRect->left = xoff + m_iWidth - pRect->left - pRect->width;
 #endif
 }
 
@@ -1242,7 +1263,8 @@ void fp_TextRun::_drawPart(UT_sint32 xoff,
 	}
 
 #ifdef BIDI_ENABLED
-	if(getVisDirection() == 1)
+	FriBidiCharType iVisDir = getVisDirection();
+	if(iVisDir == FRIBIDI_TYPE_RTL)
 	{
 		iLeftWidth = m_iWidth - iLeftWidth;
 	}
@@ -1250,7 +1272,7 @@ void fp_TextRun::_drawPart(UT_sint32 xoff,
 	for(;;)
 	{
 		bContinue = m_pBL->getSpanPtr(offset, &pSpan, &lenSpan);
-		UT_ASSERT(lenSpan>0);
+		//UT_ASSERT(lenSpan>0);
 
 		//we need special buffer for the rtl text so we could draw reversed
 		if(lenSpan > s_iSpanBuffSize) //the buffer too small, reallocate
@@ -1262,11 +1284,18 @@ void fp_TextRun::_drawPart(UT_sint32 xoff,
 		}
 	
 		UT_uint32 iTrueLen = (lenSpan > len) ? len : lenSpan;
-		UT_UCS_strncpy(s_pSpanBuff, pSpan, iTrueLen);
-	
-	
 		
-		if(getVisDirection() == 1) //rtl: determine the width of the text we are to print
+		if(m_iDirection != FRIBIDI_TYPE_ON || iVisDir != FRIBIDI_TYPE_RTL)
+			UT_UCS_strncpy(s_pSpanBuff, pSpan, iTrueLen);
+		else
+		{
+			//this is 'other neutral' visually rtl span, we need to deal
+			//with mirror characters
+			for (UT_uint32 i = 0; i < iTrueLen; i++)
+				s_pSpanBuff[i] = getMirrorChar(pSpan[i]);
+		}
+		
+		if(iVisDir == FRIBIDI_TYPE_RTL) //rtl: determine the width of the text we are to print
 		{
 			UT_UCS_strnrev(s_pSpanBuff, iTrueLen);
 			for (i= 0; i < iTrueLen; i++)
@@ -1282,7 +1311,7 @@ void fp_TextRun::_drawPart(UT_sint32 xoff,
 			break;
 		}
 
-		if(getVisDirection() == 0)
+		if(iVisDir == FRIBIDI_TYPE_LTR)
 		{
 			for(i = 0; i < iTrueLen; i++)
 			{
@@ -1300,6 +1329,9 @@ void fp_TextRun::_drawPart(UT_sint32 xoff,
 	while (bContinue)
 	{
 		bContinue = m_pBL->getSpanPtr(offset, &pSpan, &lenSpan);
+		//if(!bContinue)
+		//	break; //no span found
+			
 		UT_ASSERT(lenSpan>0);
 
 		if (len <= lenSpan)
@@ -1350,6 +1382,8 @@ void fp_TextRun::_drawInvisibleSpaces(UT_sint32 xoff, UT_sint32 yoff)
     if(findCharacter(0, UCS_SPACE) > 0){
         while(bContinue){
             bContinue = m_pBL->getSpanPtr(offset,&pSpan,&lenSpan);
+            //if(!bContinue)
+            //	break; //no span found
             UT_ASSERT(lenSpan > 0);
 
 
@@ -1485,7 +1519,9 @@ UT_sint32 fp_TextRun::findCharacter(UT_uint32 startPosition, UT_UCSChar Characte
 		while (bContinue)
 		{
 			bContinue = m_pBL->getSpanPtr(offset, &pSpan, &lenSpan);
-			UT_ASSERT(lenSpan>0);
+			//if(!bContinue)
+			//	break;
+			//UT_ASSERT(lenSpan>0);
 
 			if (len <= lenSpan)
 			{
@@ -1582,6 +1618,8 @@ bool	fp_TextRun::doesContainNonBlankData(void) const
 		while (bContinue)
 		{
 			bContinue = m_pBL->getSpanPtr(offset, &pSpan, &lenSpan);
+			//if(!bContinue)
+			//	break; //no span found
 			if(lenSpan <= 0)
 			{ 
 				fp_Line * pLine = m_pBL->getFirstLine();
@@ -1590,7 +1628,7 @@ bool	fp_TextRun::doesContainNonBlankData(void) const
 					pLine = pLine->getNext();
 				}
 			}
-			UT_ASSERT(lenSpan>0);
+			//UT_ASSERT(lenSpan>0);
 
 			if (len <= lenSpan)
 			{
@@ -1872,35 +1910,22 @@ UT_sint32 fp_TextRun::getStr(UT_UCSChar * pStr, UT_uint32 &iMax)
 	if in Unicode mode, or it will just return.
 */
 
-void fp_TextRun::setDirection(UT_sint32 dir)
+void fp_TextRun::setDirection(FriBidiCharType dir)
 {
 	if(!m_iLen)
 	{
 		return; //ignore 0-length runs, let them be treated on basis of the app defaults
 	}
 
-	UT_sint32 prevDir = m_iDirection;	
-	if(dir == -2)
+	FriBidiCharType prevDir = m_iDirection;	
+	if(dir == FRIBIDI_TYPE_UNSET)
 	{
-		if(m_iDirOverride == -1)
+		if(m_iDirOverride == FRIBIDI_TYPE_UNSET)
 		{
 			UT_UCSChar firstChar;
 			getCharacter(0, firstChar);
-
-			switch (isUCharRTL(firstChar))
-			{
-	    		case 1:
-	        		m_iDirection = 1;
-	        		break;
-	        		
-	    		case 0:
-	        		m_iDirection = 0;
-	        		break;
-	        		
-		    	default:
-		        	m_iDirection = -1;
-  			}
- 			
+			
+			m_iDirection = fribidi_get_type((FriBidiChar)firstChar);
 		}
 		else
 		{
@@ -1912,6 +1937,8 @@ void fp_TextRun::setDirection(UT_sint32 dir)
 		m_iDirection = dir;
 	}
 	
+	xxx_UT_DEBUGMSG(("fp_TextRun::setDirection: %d (passed %d, override %d, prev. %d)\n", m_iDirection, dir, m_iDirOverride, prevDir));
+	
 	setDirectionProperty(m_iDirection);
 	
 	/*
@@ -1926,10 +1953,24 @@ void fp_TextRun::setDirection(UT_sint32 dir)
 	if(m_iDirection != prevDir)
 	{
 		if(m_pLine)
-			m_pLine->addDirectionUsed(m_iDirection);
+		{
+			m_pLine->changeDirectionUsed(prevDir,m_iDirection,true);
+		}
 		clearScreen();
 	}
 	
 	//UT_DEBUGMSG(("TextRun::setDirection: direction=%d\n", m_iDirection));
 }
+
+UT_UCSChar getMirrorChar(UT_UCSChar c)
+{
+	//got to do this, otherwise bsearch screws up
+	FriBidiChar fbc = (FriBidiChar) c, mfbc;
+	
+	if (fribidi_get_mirror_char (/* Input */ fbc, /* Output */&mfbc))
+		return (UT_UCSChar) mfbc;
+	else
+		return c;
+}
+
 #endif
