@@ -46,6 +46,7 @@ class fp_Run;
 class FG_Graphic;
 class PD_Document;
 class GR_Graphics;
+class UT_Worker;
 class UT_Timer;
 class AP_TopRulerInfo;
 class AP_LeftRulerInfo;
@@ -241,6 +242,8 @@ public:
 	bool	getCharFormat(const XML_Char *** properties,bool bExpandStyles=true);
 
 	bool	setStyle(const XML_Char * style, bool bDontGeneralUpdate=false);
+	bool	setStyleAtPos(const XML_Char * style, PT_DocPosition posStart, PT_DocPosition posEnd, bool bDontGeneralUpdate=false);
+	
 	bool	getStyle(const XML_Char ** style);
 	bool appendStyle(const XML_Char ** style);
 
@@ -379,6 +382,11 @@ public:
 	void                setPreviewMode(PreViewMode pre) {m_previewMode = pre;}
 	PreViewMode         getPreviewMode(void) { return m_previewMode;}
 
+	void                setScreenUpdateOnGeneralUpdate( bool bDoit) 
+		{m_bDontUpdateScreenOnGeneralUpdate = !bDoit;}
+	bool                shouldScreenUpdateOnGeneralUpdate(void) const 
+		{ return !m_bDontUpdateScreenOnGeneralUpdate;}
+
 	inline PD_Document * getDocument (void) const {return m_pDoc;}
 
 protected:
@@ -443,8 +451,8 @@ protected:
 
 	UT_UCSChar *		_lookupSuggestion(fl_BlockLayout* pBL, fl_PartOfBlock* pPOB, UT_uint32 ndx);
 
-	static void			_autoScroll(UT_Timer * pTimer);
-	static void			_autoDrawPoint(UT_Timer * pTimer);
+	static void			_autoScroll(UT_Worker * pTimer);
+	static void			_autoDrawPoint(UT_Worker * pTimer);
 
 	// localize handling of insertion point logic
 	void				_setPoint(PT_DocPosition pt, bool bEOL = false);
@@ -456,10 +464,6 @@ protected:
 	void				_checkPendingWordForSpell(void);
 
     bool                _isSpaceBefore(PT_DocPosition pos);
-	void                _setScreenUpdateOnGeneralUpdate( bool bDoit) 
-		{m_bDontUpdateScreenOnGeneralUpdate = !bDoit;}
-	bool                _shouldScreenUpdateOnGeneralUpdate(void) const 
-		{ return !m_bDontUpdateScreenOnGeneralUpdate;}
 
 	PT_DocPosition		m_iInsPoint;
 	UT_sint32			m_xPoint;
@@ -538,7 +542,10 @@ protected:
 	ViewMode             m_viewMode;
 	PreViewMode          m_previewMode;
 	bool                 m_bDontUpdateScreenOnGeneralUpdate; 
-	bool                 m_bPieceTableState;
+	//#TF had to change the whole logic of storing PT state, since
+	//the earlier implementation did not work with nested calls to
+	//_saveAndNotifyPieceTableChange();
+	UT_uint32			m_iPieceTableState;
 };
 
 #endif /* FV_VIEW_H */
