@@ -75,13 +75,14 @@ PD_Document::PD_Document(XAP_App *pApp)
 	m_ballowListUpdates(false),
 	m_pPieceTable(0),
 	m_hashDataItems(11),
-	m_lastOpenedType(IE_Imp::fileTypeForSuffix(".abw")),
-	m_lastSavedAsType(IE_Exp::fileTypeForSuffix(".abw")),
+  m_lastOpenedType(IEFT_Bogus), // used to be: IE_Imp::fileTypeForSuffix(".abw"))
+  m_lastSavedAsType(IEFT_Bogus), // used to be: IE_Exp::fileTypeForSuffix(".abw")
 	m_bPieceTableChanging(false),
 	m_bDoingPaste(false),
 	m_bAllowInsertPointChange(true),
 	m_bRedrawHappenning(false),
-	m_bLoading(false)
+  m_bLoading(false),
+  m_bForcedDirty(false)
 {
 	m_pApp = pApp;
 
@@ -150,8 +151,10 @@ UT_Error PD_Document::importFile(const char * szFilename, int ieft,
 	m_bLoading = false;
 	updateFields();
 
-	if(markClean)	
+	if(markClean)
 		_setClean();
+	else
+	  m_bForcedDirty = true; // force this to be dirty
 
 	return UT_OK;
 }
@@ -325,13 +328,14 @@ UT_Error PD_Document::save(void)
 
 bool PD_Document::isDirty(void) const
 {
-	return m_pPieceTable->isDirty();
+	return m_pPieceTable->isDirty() || m_bForcedDirty;
 }
 
 void PD_Document::_setClean(void)
 {
 	m_pPieceTable->setClean();
 	m_pPieceTable->getFragments().cleanFrags();
+	m_bForcedDirty = false;
 }
 
 //////////////////////////////////////////////////////////////////
@@ -462,6 +466,95 @@ bool PD_Document::appendFmtMark(void)
 	return m_pPieceTable->appendFmtMark();
 }
 
+/*!
+ * This method scans the document for all styles used in the document, including
+ * styles in the basedon heiracy and the followedby list
+ * 
+ */
+void PD_Document::getAllUsedStyles(UT_Vector * pVecStyles)
+{
+	UT_sint32 i = 0;
+	pf_Frag * currentFrag = m_pPieceTable->getFragments().getFirst();
+	PD_Style * pStyle = NULL;
+	while (currentFrag!=m_pPieceTable->getFragments().getLast())
+	{
+		UT_ASSERT(currentFrag);
+//
+// get indexAP
+// get PT_STYLE_ATTRIBUTE_NAME
+// if it matches style name or is contained in a basedon name or followedby
+// 
+//
+// All this code is used to find if this frag has a style in it.
+//
+		PT_AttrPropIndex indexAP = 0;
+		if(currentFrag->getType()  == pf_Frag::PFT_Strux)
+		{
+			indexAP = static_cast<pf_Frag_Strux *>(currentFrag)->getIndexAP();
+		}
+		else if(currentFrag->getType()  == pf_Frag::PFT_Text)
+		{
+			indexAP = static_cast<pf_Frag_Text *>(currentFrag)->getIndexAP();
+		}
+		else if(currentFrag->getType()  == pf_Frag::PFT_Object)
+		{
+			indexAP = static_cast<pf_Frag_Object *>(currentFrag)->getIndexAP();
+		}
+		else if(currentFrag->getType()  == pf_Frag::PFT_FmtMark)
+		{
+			indexAP = static_cast<pf_Frag_FmtMark *>(currentFrag)->getIndexAP();
+		}
+		const PP_AttrProp * pAP = NULL;
+		m_pPieceTable->getAttrProp(indexAP,&pAP);
+		UT_ASSERT(pAP);
+		const XML_Char * pszStyleName = NULL;
+		(pAP)->getAttribute(PT_STYLE_ATTRIBUTE_NAME, pszStyleName);
+//
+// We've found a style...
+//
+		if(pszStyleName != NULL)
+		{
+			m_pPieceTable->getStyle(pszStyleName,&pStyle);
+			UT_ASSERT(pStyle);
+			if(pStyle)
+			{
+				if(pVecStyles->findItem((void *) pStyle) < 0)
+				{
+					pVecStyles->addItem((void *) pStyle);
+				}
+				PD_Style * pBasedOn = pStyle->getBasedOn();
+				i = 0;
+				while(pBasedOn != NULL && i <  pp_BASEDON_DEPTH_LIMIT)
+				{
+					if(pVecStyles->findItem((void *) pBasedOn) < 0)
+					{
+						pVecStyles->addItem((void *) pBasedOn);
+					}
+					i++;
+					pBasedOn = pBasedOn->getBasedOn();
+				}
+				PD_Style * pFollowedBy = pStyle->getFollowedBy();
+				if(pFollowedBy && (pVecStyles->findItem((void *) pFollowedBy) < 0))
+				{
+					pVecStyles->addItem((void *) pFollowedBy);
+				}
+			}
+		}
+//
+// Get Next frag in the table.
+//
+		currentFrag = currentFrag->getNext();
+	}
+//
+// Done!
+//
+}		
+					
+/*!
+ * This method removes the style of name pszName from the styles definition and removes
+ * all instances of it from the document including the basedon heiracy and the 
+ * followed-by sequences.
+ */
 bool PD_Document::removeStyle(const XML_Char * pszName)
 {
 	UT_ASSERT(m_pPieceTable);
@@ -481,6 +574,10 @@ bool PD_Document::removeStyle(const XML_Char * pszName)
 	}
 	else
 	{
+//
+// The name of the style is stored in the PT_NAME_ATTRIBUTE_NAME attribute within the
+// style
+//
 		pNormal->getAttribute(PT_NAME_ATTRIBUTE_NAME, szBack);
 	}
 	UT_ASSERT(szBack);
@@ -1287,7 +1384,7 @@ bool PD_Document::enumDataItems(UT_uint32 k,
 	    // noop
 	  }
 
-	if (ppHandle)
+	if (ppHandle && c.is_valid())
 		*ppHandle = (void *)pHashEntry;
 
 	struct _dataItemPair* pPair = (struct _dataItemPair*)pHashEntry;
@@ -1344,9 +1441,12 @@ bool PD_Document::_syncFileTypes(bool bOpenedFromSaved)
 	const char *szSuffixes;
 
 	if (bOpenedFromSaved)
-		szSuffixes = IE_Exp::suffixesForFileType(m_lastSavedAsType);
+	  szSuffixes = IE_Imp::suffixesForFileType(m_lastOpenedType);
 	else
-		szSuffixes = IE_Imp::suffixesForFileType(m_lastOpenedType);
+	  szSuffixes = IE_Exp::suffixesForFileType(m_lastSavedAsType);
+
+	if (!szSuffixes)
+	  return IEFT_Bogus;
 
 	// Pull first suffix from the file dialog pattern string
 	UT_String suffix;
@@ -1612,15 +1712,18 @@ bool   PD_Document::updateDocForStyleChange(const XML_Char * szStyle,
 					PD_Style * cStyle = NULL;
 					m_pPieceTable->getStyle(pszStyleName,&cStyle);
 					UT_ASSERT(cStyle);
-					PD_Style * pBasedOn = cStyle->getBasedOn();
-					UT_uint32 i =0;
-					for(i=0; (i < pp_BASEDON_DEPTH_LIMIT) && (pBasedOn != NULL) && (pBasedOn!= pStyle); i++)
+					if(cStyle)
 					{
-						pBasedOn = pBasedOn->getBasedOn();
-					}
-					if(pBasedOn == pStyle)
-					{
-						bUpdate = true;
+						PD_Style * pBasedOn = cStyle->getBasedOn();
+						UT_uint32 i =0;
+						for(i=0; (i < pp_BASEDON_DEPTH_LIMIT) && (pBasedOn != NULL) && (pBasedOn!= pStyle); i++)
+						{
+							pBasedOn = pBasedOn->getBasedOn();
+						}
+						if(pBasedOn == pStyle)
+						{
+							bUpdate = true;
+						}
 					}
 				}
 				if(bUpdate)
@@ -1656,6 +1759,7 @@ bool   PD_Document::updateDocForStyleChange(const XML_Char * szStyle,
 				UT_ASSERT(pAP);
 				const XML_Char * pszStyleName = NULL;
 				(pAP)->getAttribute(PT_STYLE_ATTRIBUTE_NAME, pszStyleName);
+
 //
 // It does so signal all the layouts to update themselves for the new definition
 // of the style.
