@@ -59,6 +59,7 @@
 
 #include "fp_Run.h"
 #include "ut_Win32OS.h"
+#include "ut_Win32Idle.h"
 
 #include "ie_impexp_Register.h"
 
@@ -793,21 +794,25 @@ int AP_Win32App::WinMain(const char * szAppName, HINSTANCE hInstance,
 
 	if (bShowApp)
 	{
-		while (GetMessage(&msg, NULL, 0, 0))
-		{
-			// Note: we do not call TranslateMessage() because
-			// Note: the keybinding mechanism is responsible
-			// Note: for deciding if/when to do this.
-
-			if( pMyWin32App->handleModelessDialogMessage( &msg ) )
+		while( GetMessage(&msg, NULL, 0, 0) )
+	    {
+   	      	// TranslateMessage is not called because AbiWord
+	      	// has its own way of decoding keyboard accelerators
+	      	if (pMyWin32App->handleModelessDialogMessage(&msg)) 
 				continue;
+	    	DispatchMessage(&msg);	
 
-			DispatchMessage(&msg);
-		}
+			// Check for idle condition
+			while( !UT_Win32Idle::_isEmpty() &&
+                   !PeekMessage(&msg, NULL, 0, 0, PM_NOREMOVE) ) 
+			{
+				// Fire idle functions when no pending messages
+		    	UT_Win32Idle::_fireall();
+			}
+	    }
 	}
-
+	
 	// destroy the App.  It should take care of deleting all frames.
-
 	pMyWin32App->shutdown();
 	delete pMyWin32App;
 
@@ -932,7 +937,12 @@ void AP_Win32App::ParseCommandLine(int iCmdShow)
 					kWindowsOpened++;
 
 					HWND hwnd = pFirstWin32Frame->getTopLevelWindow();
-					pFirstWin32Frame->show();
+					//pFirstWin32Frame->show();
+					if (kWindowsOpened > 1) // only set 1st opened window to stored state
+						ShowWindow(hwnd, iCmdShow);
+					else
+						ShowWindow(hwnd, setupWindowFromPrefs(iCmdShow, hwnd));
+					UpdateWindow(hwnd);
 				}
 				else
 				{
@@ -946,7 +956,10 @@ void AP_Win32App::ParseCommandLine(int iCmdShow)
 					kWindowsOpened++;
 					pFirstWin32Frame->loadDocument(NULL, IEFT_Unknown);
 					HWND hwnd = pFirstWin32Frame->getTopLevelWindow();
+					if (kWindowsOpened > 1) // only set 1st opened window to stored state
 					ShowWindow(hwnd, iCmdShow);
+					else
+						ShowWindow(hwnd, setupWindowFromPrefs(iCmdShow, hwnd));
 					UpdateWindow(hwnd);
 #else
 					delete pFirstWin32Frame;
@@ -969,7 +982,7 @@ void AP_Win32App::ParseCommandLine(int iCmdShow)
 		pFirstWin32Frame->loadDocument(NULL, IEFT_Unknown);
 
 		HWND hwnd = pFirstWin32Frame->getTopLevelWindow();
-		ShowWindow(hwnd, iCmdShow);
+		ShowWindow(hwnd, setupWindowFromPrefs(iCmdShow, hwnd));
 		UpdateWindow(hwnd);
 	}
 
