@@ -785,15 +785,15 @@ void AP_Dialog_Lists::fillDialogFromBlock(void)
 	//
 	if(va.getItemCount()>0)
 	{	
-		i = findVecItem(&va,"style");
-		if( i>= 0)
-		{
-			m_DocListType = getBlock()->getListTypeFromStyle( (const XML_Char *) va.getNthItem(i+1));
-		}
-		else
-		{
-			m_DocListType = NUMBERED_LIST;
-		}
+//  		i = findVecItem(&va,PT_STYLE_ATTRIBUTE_NAME);
+//  		if( i>= 0)
+//  		{
+//  			m_DocListType = getBlock()->getListTypeFromStyle( (const XML_Char *) va.getNthItem(i+1));
+//  		}
+//  		else 
+//  		{
+//  			m_DocListType = NUMBERED_LIST;
+//  		}
 
 		i = findVecItem(&va,"level");
 		if( i>= 0)
@@ -875,6 +875,16 @@ UT_uint32 AP_Dialog_Lists::getID(void)
  * key in this props vector
  */
 UT_sint32  AP_Dialog_Lists::findVecItem(UT_Vector * v, char * key)
+{
+	const char* const_key = key;
+	return findVecItem( v, const_key);
+}
+
+/*!
+ * This method returns the index to the value corresponding to the 
+ * key in this props vector
+ */
+UT_sint32  AP_Dialog_Lists::findVecItem(UT_Vector * v, const char * key)
 {
 	UT_sint32 i = v->getItemCount();
 	if(i < 0) 
