@@ -44,8 +44,8 @@ BeginSet(en,US,true)
 	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Close", 			"Close the document")
 	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Save", 			"Save the document")
 	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Save &As", 		"Save the document under a different name")
-	MenuLabel(AP_MENU_ID_FILE_IMPORT,       "&Import",			"Import the document")
-	MenuLabel(AP_MENU_ID_FILE_EXPORT,       "&Export",			"Save the document without changing the current name")
+	MenuLabel(AP_MENU_ID_FILE_IMPORT,       "Op&en Copy",			"Import the document")
+	MenuLabel(AP_MENU_ID_FILE_EXPORT,       "Sa&ve Copy",			"Save the document without changing the current name")
 
 	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"Page Set&up",		"Change the printing options")
 	MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Print",			"Print all or part of the document")
@@ -98,8 +98,8 @@ BeginSet(en,US,true)
      MenuLabel(AP_MENU_ID_VIEW_ZOOM_100, "Zoom to &100%", "Zoom to 100%")
      MenuLabel(AP_MENU_ID_VIEW_ZOOM_75, "Zoom to &75%", "Zoom to 75%")
      MenuLabel(AP_MENU_ID_VIEW_ZOOM_50, "Zoom to &50%", "Zoom to 50%")
-     MenuLabel(AP_MENU_ID_VIEW_ZOOM_WIDTH, "Zoom to &Whole Page", "Zoom to Whole Page")
-     MenuLabel(AP_MENU_ID_VIEW_ZOOM_WHOLE, "Zoom to &Page Width", "Zoom to Page Width")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_WIDTH, "Zoom to &Page Width", "Zoom to page width")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_WHOLE, "Zoom to &Whole Page", "Zoom to whole page")
 
 	MenuLabel(AP_MENU_ID_INSERT,			"&Insert",			NULL)
 	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Break",			"Insert a page, column, or section break")
@@ -143,7 +143,7 @@ BeginSet(en,US,true)
 	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Preferences",		"Set preferences")
 	MenuLabel(AP_MENU_ID_TOOLS_LANGUAGE, "&Language", "Change the language of the selected text")
 	MenuLabel(AP_MENU_ID_TOOLS_PLUGINS, "P&lugins", "Manage plugins")
-	MenuLabel(AP_MENU_ID_TOOLS_SCRIPTS, "S&cripts", "Exectute helper scripts")
+	MenuLabel(AP_MENU_ID_TOOLS_SCRIPTS, "S&cripts", "Execute helper scripts")
 
 	MenuLabel(AP_MENU_ID_ALIGN,				"&Align",			NULL)
 	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Left",			"Left-justify the paragraph")
