@@ -47,8 +47,8 @@ BeginSetEnc(it,IT,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Chiudi", 			"Chiude il documento")
 	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Salva", 			"Salva il documento")
 	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Sa&lva con nome", 	"Salva il documento sotto un altro nome")
-	MenuLabel(AP_MENU_ID_FILE_IMPORT,       "&Importa",			"Importa il documento")
-	MenuLabel(AP_MENU_ID_FILE_EXPORT,       "&Esporta",			"Salva il documento senza cambiarne il nome")
+	MenuLabel(AP_MENU_ID_FILE_IMPORT,       	"&Apri copia",			"Importa il documento")
+	MenuLabel(AP_MENU_ID_FILE_EXPORT,       	"&Salva copia",			"Salva il documento senza cambiarne il nome")
 
 	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"&Imposta pagina",	"Cambia le opzioni di stampa")
 	MenuLabel(AP_MENU_ID_FILE_PRINT,		"Stam&pa",			"Stampa tutto o parte del documento")
@@ -172,7 +172,7 @@ BeginSetEnc(it,IT,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Dispondi tutto",		"Visualizza tutta la lista delle finestre")
 
 	MenuLabel(AP_MENU_ID_HELP,				"&Aiuto",					NULL)
-	MenuLabel(AP_MENU_ID_HELP_CREDITS, 		"C&rediti", 		"Mostra i crediti")
+	MenuLabel(AP_MENU_ID_HELP_CREDITS, 		"&Riconoscimenti", 		"Riconoscimenti e ringraziamenti")
 	MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"&Contenuto dell'Aiuto",	"Mostra il contenuto dell'Aiuto")
 	MenuLabel(AP_MENU_ID_HELP_INDEX,		"&Indice",		"Mostra l'indice")
 	MenuLabel(AP_MENU_ID_HELP_CHECKVER,		"Mostra la &Versione",	"Mostra il numero di versione del programma")
