@@ -81,19 +81,26 @@ BeginSetEnc(nn,NO,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_EDIT_REMOVEFOOTER,			"Fjern bot&ntekst",			"Fjernar botnteksten p denne sida fr dokumentet")
 	
 	MenuLabel(AP_MENU_ID_VIEW,				"&Vis",			NULL)
-        MenuLabel(AP_MENU_ID_VIEW_NORMAL, "&Normal", "Normalvising")
+        MenuLabel(AP_MENU_ID_VIEW_NORMAL, "&Normaloppsett", "Normalvising")
         MenuLabel(AP_MENU_ID_VIEW_WEB, "&Vevoppsett", "Vevoppsett")
         MenuLabel(AP_MENU_ID_VIEW_PRINT, "&Utskriftsoppsett", "Utskriftsoppsett")
 	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Verktylinjer",		NULL)
 	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standard",		"Viser eller skjuler standardverktylinja")
 	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Formatering",		"Viser eller skjuler formateringsverktylinja")
 	MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,		"&Ekstra",			"Viser eller skjuler ekstraverktylinja")
-	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Linjal",			"Viser eller skjuler linjalar")
-	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"&Statuslinje",		"Viser eller skjuler statuslinja")
+	MenuLabel(AP_MENU_ID_VIEW_RULER,		"Vis &Linjal",			"Viser eller skjuler linjalar")
+	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"Vis &Statuslinje",		"Viser eller skjuler statuslinja")
 	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"Vis &avsnittsmerke",	"Viser eller skjuler teikn som ikkje blir skrivne ut")
 	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Topptekst og botntekst",	"Viser tekst p toppen eller botnen av kvar side")
         MenuLabel(AP_MENU_ID_VIEW_FULLSCREEN, "F&ullskjerm", "Viser dokumentet over heile skjermen")
-	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Forstrring ",			"Endrar visingsstorleiken p skjermen")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_MENU, "&Forstrring ",			"Endrar visingsstorleiken p skjermen")
+	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Forstrring",			"Endrar visingsstorleiken p skjermen")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_200, "Forstrr til &200 %", "Forstrr til 200 %")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_100, "Forstrr til &100 %", "Forstrr til 100 %")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_75, "Forstrr til &75 %", "Forstrr til 75 %")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_50, "Forstrr til &50 %", "Forstrr til 50 %")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_WIDTH, "Forstrr til &heile sida", "Forstrr til heile sida")
+     MenuLabel(AP_MENU_ID_VIEW_ZOOM_WHOLE, "Forstrr til &sidebreidd", "Forstrr til sidebreidd")
 
 	MenuLabel(AP_MENU_ID_INSERT,			"Sett &inn",			NULL)
 	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Skift ",			"Sett inn side-, spalte- eller inndelingsskift")
@@ -107,7 +114,7 @@ BeginSetEnc(nn,NO,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,	"&Fr fil ",			"Sett inn eit bilde fr ei grafikkfil")
 
 	MenuLabel(AP_MENU_ID_FORMAT,			"F&ormat",			NULL)
-	MenuLabel(AP_MENU_ID_FMT_LANGUAGE,		"S&prk",		"Endrar sprket til merkt tekst")
+	MenuLabel(AP_MENU_ID_FMT_LANGUAGE,		"Vel s&prk",		"Endrar sprket til merkt tekst")
 	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Skrift ",			"Endrar skrift p merkt tekst")
 	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Avsnitt ",		"Endrar utsjnaden til merkt avsnitt")
 	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"&Punktmerking og nummerering ",	"Legg til eller endrar punktmerking eller nummerering for merkt(e) avsnitt")
@@ -132,6 +139,7 @@ BeginSetEnc(nn,NO,true,"iso-8859-1")
         MenuLabel(AP_MENU_ID_TOOLS_SPELLING, "&Stavekontroll", NULL)
 	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Stavekontroll ",		"Stavekontrollerer dokumentet")
         MenuLabel(AP_MENU_ID_TOOLS_AUTOSPELL, "&Fortlpande stavekontroll", "Fortlpande stavekontroll av dokumentet")
+     MenuLabel(AP_MENU_ID_TOOLS_SPELLPREFS, "Stavekontroll&innstillingar", "Endrar stavekontrollinnstillingar")
 	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,	"Ordt&elling ",		"Tel talet p ord i dokumentet")
 	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Innstillingar ",			"Endrar innstillingar")
         MenuLabel(AP_MENU_ID_TOOLS_LANGUAGE, "S&prk ", "Endrar sprket til merkt tekst")
@@ -162,14 +170,15 @@ BeginSetEnc(nn,NO,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"Fleire &vindauge",	"Viser eit liste over vindauge")
 
 	MenuLabel(AP_MENU_ID_HELP,			"&Hjelp",			NULL)
+     MenuLabel(AP_MENU_ID_HELP_CREDITS, "&Bidragsytarar", "Informasjon om utviklarane av AbiWord")
 	MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"&Innhald i Hjelp",	"Viser innhaldet i Hjelp")
 	MenuLabel(AP_MENU_ID_HELP_INDEX,		"&Stikkordregister i Hjelp",		"Viser stikkordregisteret i Hjelp")
 	MenuLabel(AP_MENU_ID_HELP_CHECKVER,		"Kontroller &versjon",	"Kontrollerer versjonsnummeret til AbiWord")
 	MenuLabel(AP_MENU_ID_HELP_SEARCH,		"Sk &etter hjelp om ...",	"Sker etter eit emne i Hjelp")
 	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Om %s ",		"Viser informasjon om programmet, versjonsnummer og opphavsrett")
 	MenuLabel(AP_MENU_ID_HELP_ABOUTOS,		"Om o&pen kjeldekode ",	"Viser informasjon om open kjeldekode-prinsippet")
-	MenuLabel(AP_MENU_ID_HELP_ABOUT_GNU, "Om &GNU Free Software ", "Viser informasjon om GNU-prosjektet")
-	MenuLabel(AP_MENU_ID_HELP_ABOUT_GNOMEOFFICE, "Om G&NOME Office ", "Viser informasjon om GNOME Office-prosjektet")
+     MenuLabel(AP_MENU_ID_HELP_ABOUT_GNU, "Om &GNU Free Software ", "Viser informasjon om GNU-prosjektet")
+     MenuLabel(AP_MENU_ID_HELP_ABOUT_GNOMEOFFICE, "Om G&NOME Office ", "Viser informasjon om GNOME Office-prosjektet")
 
 	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"Erstatt med denne stavemten")
 	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"Erstatt med denne stavemten")
