@@ -17,9 +17,6 @@
  * 02111-1307, USA.
  */
 
-/* Portuguese translations provided by:
- * 	Rui M. Silva Seabra <rms@greymalkin.yi.org>
- */
 
 /*****************************************************************
 ******************************************************************
@@ -42,83 +39,90 @@ BeginSetEnc(pt,PT,true,"iso-8859-1")
     //       (id,                           szLabel,            szStatusMsg)
 
     MenuLabel(AP_MENU_ID_FILE,			"&Ficheiro",		NULL)
-    MenuLabel(AP_MENU_ID_FILE_NEW,		"&Novo",		"Criar um novo documento")    
-    MenuLabel(AP_MENU_ID_FILE_OPEN,		"&Abrir",		"Abrir um documento")
-    MenuLabel(AP_MENU_ID_FILE_CLOSE,		"Fe&char",		"Fechar o documento")
+    MenuLabel(AP_MENU_ID_FILE_NEW,		"&Novo",		"Criar novo documento")    
+    MenuLabel(AP_MENU_ID_FILE_OPEN,		"&Abrir",		"Abrir documento")
+    MenuLabel(AP_MENU_ID_FILE_CLOSE,		"Fe&char",		"Fechar documento")
     MenuLabel(AP_MENU_ID_FILE_SAVE,		"&Gravar",		"Gravar documento")
-    MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Gra&var como",		"Gravar ficheiro atribuindo um nome")
-    MenuLabel(AP_MENU_ID_FILE_IMPORT,		"&Importar",		"Importar um documento para a posicao do cursor neste documento")
-    MenuLabel(AP_MENU_ID_FILE_EXPORT,		"&Exportar",		"Gravar uma cpia do documento com outro nome")
+    MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Gra&var como",		"Gravar documento com novo nome")
+    MenuLabel(AP_MENU_ID_FILE_IMPORT,		"&Importar",		"Importar documento para a posio actual do cursor")
+    MenuLabel(AP_MENU_ID_FILE_EXPORT,		"&Exportar",		"Gravar cpia do documento com novo nome")
 
-    MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"&Paginao",		"Modificar o paginamento")
-    MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Imprimir",		"Imprimir o documento")
-    MenuLabel(AP_MENU_ID_FILE_PRINT_DIRECTLY,	"Imprimir &Directamente","Imprimir o documento com o driver interno de PostScript")
-    MenuLabel(AP_MENU_ID_FILE_PRINT_PREVIEW,	"Ver Antes",		"Ver o documento antes de o imprimir")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",		"ltimo ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",		"Segundo ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",		"Terceiro ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",		"Quarto ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",		"Quinto ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",		"Sexto ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",		"Sptimo ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",		"Oitavo ficheiro aberto")
-    MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",		"Nono ficheiro aberto")
+    MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"&Paginao",		"Modificar Paginao")
+    MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Imprimir",		"Imprimir documento")
+    MenuLabel(AP_MENU_ID_FILE_PRINT_DIRECTLY,	"Imprimir &Directamente","Imprimir documento com o driver interno de PostScript")
+    MenuLabel(AP_MENU_ID_FILE_PRINT_PREVIEW,	"Ver Antes",		"Ver documento antes de imprimir")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",		"ltimo documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",		"Penltimo documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",		"Antepenltimo documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",		"Quarto documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",		"Quinto documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",		"Sexto documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",		"Sptimo documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",		"Oitavo documento utilizado")
+    MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",		"Nono documento utilizado")
     MenuLabel(AP_MENU_ID_FILE_EXIT,		"&Sair",		"Fechar todas as janelas e sair")
 
     MenuLabel(AP_MENU_ID_EDIT,			"&Editar",		NULL)
-    MenuLabel(AP_MENU_ID_EDIT_UNDO,		"&Anular",		"Anular a ltima operao")
-    MenuLabel(AP_MENU_ID_EDIT_REDO,		"&Repetir",		"Repetir a ltima operao")
-    MenuLabel(AP_MENU_ID_EDIT_CUT,		"Co&rtar",		"Cortar a seleco")
-    MenuLabel(AP_MENU_ID_EDIT_COPY,		"&Copiar",		"Copiar a seleco")
-    MenuLabel(AP_MENU_ID_EDIT_PASTE,		"Co&lar",		"Colar a seleco")
-    MenuLabel(AP_MENU_ID_EDIT_PASTE_SPECIAL,	"Colar &Especial",	"Colar um objecto no formatado")
-    MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"Apa&gar",		"Apagar a seleco")
-    MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"Seleccionar &tudo",	"Seleccionar o documento inteiro")
-    MenuLabel(AP_MENU_ID_EDIT_FIND,		"&Procurar",		"Procurar texto")
+    MenuLabel(AP_MENU_ID_EDIT_UNDO,		"&Desfazer",		"Cancelar ltima aco")
+    MenuLabel(AP_MENU_ID_EDIT_REDO,		"&Refazer",		"Refazer ltima aco cancelada")
+    MenuLabel(AP_MENU_ID_EDIT_CUT,		"Co&rtar",		"Cortar seleco")
+    MenuLabel(AP_MENU_ID_EDIT_COPY,		"&Copiar",		"Copiar seleco")
+    MenuLabel(AP_MENU_ID_EDIT_PASTE,		"Co&lar",		"Colar seleco")
+    MenuLabel(AP_MENU_ID_EDIT_PASTE_SPECIAL,	"Colar &Especial",	"Colar objecto no formatado")
+    MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"Apa&gar",		"Apagar seleco")
+    MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"Seleccionar &tudo",	"Seleccionar todo o documento")
+    MenuLabel(AP_MENU_ID_EDIT_FIND,		"&Procurar",		"Procurar no documento")
     MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"&Substituir",		"Substituir no documento")
     MenuLabel(AP_MENU_ID_EDIT_GOTO,		"&Ir para",		"Deslocar o cursor para")
-    MenuLabel(AP_MENU_ID_EDIT_EDITHEADER,	"Editar &Cabealho",	"Editar o cabealho da pgina")
-    MenuLabel(AP_MENU_ID_EDIT_EDITFOOTER,	"Editar &Rodap",	"Editar o rodap da pgina")
-    MenuLabel(AP_MENU_ID_EDIT_REMOVEHEADER,	"Remover Cabealho",	"Remover o cabealho desta pgina do documento")
-    MenuLabel(AP_MENU_ID_EDIT_REMOVEFOOTER,	"Remover Rodap",	"Remover o rodap desta pgina do documento")
+    MenuLabel(AP_MENU_ID_EDIT_EDITHEADER,	"Editar &Cabealho",	"Editar cabealho")
+    MenuLabel(AP_MENU_ID_EDIT_EDITFOOTER,	"Editar &Rodap",	"Editar rodap")
+    MenuLabel(AP_MENU_ID_EDIT_REMOVEHEADER,	"Remover Cabealho",	"Remover cabealho")
+    MenuLabel(AP_MENU_ID_EDIT_REMOVEFOOTER,	"Remover Rodap",	"Remover rodap")
 
     MenuLabel(AP_MENU_ID_VIEW,			"&Ver",			NULL)
-    MenuLabel(AP_MENU_ID_VIEW_NORMAL,		"Vista Normal",		"Vista Normal")
-    MenuLabel(AP_MENU_ID_VIEW_WEB,		"Layout &Web",		"Ver documento como pgina WWW")
+    MenuLabel(AP_MENU_ID_VIEW_NORMAL,		"Esquema Normal",	"Esquema Normal")
+    MenuLabel(AP_MENU_ID_VIEW_WEB,		"Esquema &Web",		"Ver documento como pgina WWW")
     MenuLabel(AP_MENU_ID_VIEW_PRINT,		"Layout de &Impresso",	"Ver documento como se impresso")
     MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Barras de utilitrios", NULL)
-    MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standard",		"Ver/Omitir barra standard")
-    MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Formatao",		"Ver/Omitir barra de formatao")
-    MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,		"&Extra",		"Ver/Omitir barra Extra")
-    MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Rguas",		"Ver/Omitir as rguas")
-    MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"Barra de &mensagens",	"Ver/Omitir a barra de mensagens")
-    MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"M&ostrar ",		"Ver/Omitir caracteres no imprimveis")
+    MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Standard",		"Ver/Omitir Barra Standard")
+    MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Formatao",		"Ver/Omitir Barra de Formatao")
+    MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,		"&Extra",		"Ver/Omitir Barra Extra")
+    MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Rguas",		"Ver/Omitir Rguas")
+    MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"Barra de &mensagens",	"Ver/Omitir Barra de Mensagens")
+    MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"M&ostrar ",		"Ver/Omitir Caracteres No Imprimveis")
     MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Cabealhos e Rodaps","Editar os cabealhos e rodaps")
     MenuLabel(AP_MENU_ID_VIEW_FULLSCREEN,	"&S a Pgina",		"Mostrar somente as pginas")
     MenuLabel(AP_MENU_ID_VIEW_ZOOM,		"&Zoom",		"Aproximar ou afastar do texto")
+    MenuLabel(AP_MENU_ID_VIEW_ZOOM_MENU,	"&Zoom",		"Aproximar ou afastar do texto")
+    MenuLabel(AP_MENU_ID_VIEW_ZOOM_200,		"Zoom to &200%",	"Zoom a 200%")
+    MenuLabel(AP_MENU_ID_VIEW_ZOOM_100,		"Zoom to &100%",	"Zoom a 100%")
+    MenuLabel(AP_MENU_ID_VIEW_ZOOM_75,		"Zoom to &75%",		"Zoom a 75%")
+    MenuLabel(AP_MENU_ID_VIEW_ZOOM_50,		"Zoom to &50%",		"Zoom a 50%")
+    MenuLabel(AP_MENU_ID_VIEW_ZOOM_WIDTH,	"Zoom to &Page Width",	"Zoom  largura da pgina")
+    MenuLabel(AP_MENU_ID_VIEW_ZOOM_WHOLE,	"Zoom to &Whole Page",	"Zoom  pgina inteira")
 
     MenuLabel(AP_MENU_ID_INSERT,		"&Inserir",		NULL)
-    MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Quebra",		"Inserir quebras de pgina, seco")
-    MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"&Nmerao",		"Inserir nmerao das pginas")
+    MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Quebra",		"Inserir quebras de pgina, seco...")
+    MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"&Nmerao",		"Inserir nmerao de pginas")
     MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"Data e &Hora",		"Inserir data e hora")
-    MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Campo",		"Inserir um campo calculado")
+    MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Campo",		"Inserir campo calculado")
     MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Smbolo",		"Inserir caracteres especiais")
-    MenuLabel(AP_MENU_ID_INSERT_ENDNOTE,	"Nota &Final",		"Inserir uma nota final")
-    MenuLabel(AP_MENU_ID_INSERT_PICTURE,	"&Imagem",		"Inserir uma imagem")
+    MenuLabel(AP_MENU_ID_INSERT_ENDNOTE,	"Nota &Final",		"Inserir nota final")
+    MenuLabel(AP_MENU_ID_INSERT_PICTURE,	"&Imagem",		"Inserir imagem")
     MenuLabel(AP_MENU_ID_INSERT_CLIPART,	"&Portfolio",		"Inserir grficos do portfolio")
     MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,	"Do &Ficheiro",		"Inserir uma imagem a partir de um ficheiro")
 
     MenuLabel(AP_MENU_ID_FORMAT,		"F&ormatar",		NULL)
-    MenuLabel(AP_MENU_ID_FMT_LANGUAGE,		"&Lngua",		"Mudar a lgua da rea seleccionada")
-    MenuLabel(AP_MENU_ID_FMT_FONT,		"&Tipo",		"Mudar o tipo de letra")
-    MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Pargrafo",		"Mudar a definio do pargrafo")
+    MenuLabel(AP_MENU_ID_FMT_LANGUAGE,		"&Lngua",		"Mudar lgua da rea seleccionada")
+    MenuLabel(AP_MENU_ID_FMT_FONT,		"&Tipo",		"Mudar tipo de letra")
+    MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"&Pargrafo",		"Mudar definio do pargrafo")
     MenuLabel(AP_MENU_ID_FMT_BULLETS,		"&Listas",		"Formatar listas (no) numeradas")
     MenuLabel(AP_MENU_ID_FMT_DOCUMENT,		"&Documento",		"Formatar propriedades do documento, tais como tamanho do papel e margens")
     MenuLabel(AP_MENU_ID_FMT_BORDERS,		"Bordas e &Sombras",	"ajustar bordas e sombreados")
     MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"C&olunas",		"Mudar o nmero de colunas")
-    MenuLabel(AP_MENU_ID_FMT_TOGGLECASE,	"&Maisculas/Minsculas","Mudar a capitalizao da rea seleccionada")
-    MenuLabel(AP_MENU_ID_FMT_BACKGROUND,	"&Cor de Fundo",	"Mudar a cor de fundo do documento")
-    MenuLabel(AP_MENU_ID_FMT_STYLE,		"&Estilo",		"Definir ou aplicar estilos a uma seleco")
+    MenuLabel(AP_MENU_ID_FMT_TOGGLECASE,	"&Maisculas/Minsculas","Mudar capitalizao da rea seleccionada")
+    MenuLabel(AP_MENU_ID_FMT_BACKGROUND,	"&Cor de Fundo",	"Mudar cor de fundo")
+    MenuLabel(AP_MENU_ID_FMT_STYLE,		"&Estilo",		"Definir ou aplicar estilos")
     MenuLabel(AP_MENU_ID_FMT_TABS,		"Ta&bulao",		"Definir tabulao")
     MenuLabel(AP_MENU_ID_FMT_BOLD,		"&Negrito",		"Engrossar texto")
     MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Itlico",		"Inclinar texto")
@@ -134,6 +138,7 @@ BeginSetEnc(pt,PT,true,"iso-8859-1")
     MenuLabel(AP_MENU_ID_TOOLS_SPELLING,	"&Ortografia",		NULL)
     MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"Verificar agora",	"Verificar ortografia do documento agora")
     MenuLabel(AP_MENU_ID_TOOLS_AUTOSPELL,	"Verificao &Automtica","Verificar ortografia do documento automaticamente")
+    MenuLabel(AP_MENU_ID_TOOLS_SPELLPREFS,	"&Opes de Ortografia", "Definir opes de ortografia")
     MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,	"&Contar palavras",	"Contar palavras no documento")
     MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Opes",		"Configurar as opes")
     MenuLabel(AP_MENU_ID_TOOLS_LANGUAGE,	"&Lngua",		"Mudar a lngua da rea seleccionada")
@@ -165,13 +170,13 @@ BeginSetEnc(pt,PT,true,"iso-8859-1")
 
     MenuLabel(AP_MENU_ID_HELP,			"&Ajuda",		NULL)
     MenuLabel(AP_MENU_ID_HELP_CREDITS,		"C&rditos",		"Mostrar crditos")
-    MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"&Tpicos da Ajuda",	"Mostrar tpicos da ajuda")
+    MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"&Tpicos de Ajuda",	"Mostrar tpicos de ajuda")
     MenuLabel(AP_MENU_ID_HELP_INDEX,		"&Index da Ajuda",	"Mostrar o Index da ajuda")
     MenuLabel(AP_MENU_ID_HELP_CHECKVER,		"&Verso",		"Mostrar verso do AbiWord")
-    MenuLabel(AP_MENU_ID_HELP_SEARCH,		"&Pesquisar na Ajuda",	"Pesquiser ajuda sobre...")
-    MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Acerca de %s",	"Ver informaes sobre o programa, nmero de versao e copyrights")
+    MenuLabel(AP_MENU_ID_HELP_SEARCH,		"&Pesquisar na Ajuda",	"Pesquisar ajuda sobre...")
+    MenuLabel(AP_MENU_ID_HELP_ABOUT,		"&Acerca de %s",	"Ver informaes sobre o programa, nmero de verso e copyrights")
     MenuLabel(AP_MENU_ID_HELP_ABOUTOS,		"Acerca de &Open Source",	"Mostrar informao a respeito de Open Source")
-    MenuLabel(AP_MENU_ID_HELP_ABOUT_GNU,	"Acerca do Software Livre &GNU", "Saiba mais sobre o projecto GNU")
+    MenuLabel(AP_MENU_ID_HELP_ABOUT_GNU,	"Acerca do Software Livre &GNU", "Saiba mais sobre o Software Livre e o Projecto GNU")
     MenuLabel(AP_MENU_ID_HELP_ABOUT_GNOMEOFFICE, "Acerca do G&NOME Office", "Saiba mais sobre o projecto GNOME Office")
 
     MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",			"Mudar para a sugesto")
