@@ -48,31 +48,31 @@ BeginSetEnc(pt,PT,true,"iso-8859-1")
 
 	//          (id, 		                    szLabel,	IconName,     	szToolTip,      szStatusMsg)
 
-	ToolbarLabel(AP_TOOLBAR_ID_FILE_NEW,		"Novo",		tb_new_xpm,		NULL,	"Criar um novo documento")	
-	ToolbarLabel(AP_TOOLBAR_ID_FILE_OPEN,		"Abrir",	tb_open_xpm,		NULL,	"Abrir um documento existente")
-	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVE,		"Gravar",	tb_save_xpm,		NULL,	"Gravar o documento")
-	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVEAS,		"Gravar como",	tb_save_as_xpm,		NULL,	"Gravar o documento com um nome diferente")
-	ToolbarLabel(AP_TOOLBAR_ID_FILE_PRINT,		"Imprimir",	tb_print_xpm,		NULL,	"Imprimir o documento")
-	ToolbarLabel(AP_TOOLBAR_ID_FILE_PRINT_PREVIEW,	"Ver Antes",	tb_print_preview_xpm,	NULL,	"Ver o documento antes de o imprimir")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_UNDO,		"Desfazer",	tb_undo_xpm,		NULL,	"Desfazer a edio")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REDO,		"Refazer",	tb_redo_xpm,		NULL,	"Refazer a edio")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_CUT,		"Corta",	tb_cut_xpm,		NULL,	"Cortar")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_COPY,		"Copiar",	tb_copy_xpm,		NULL,	"Copiar")
+	ToolbarLabel(AP_TOOLBAR_ID_FILE_NEW,		"Novo",		tb_new_xpm,		NULL,	"Criar novo documento")	
+	ToolbarLabel(AP_TOOLBAR_ID_FILE_OPEN,		"Abrir",	tb_open_xpm,		NULL,	"Abrir documento")
+	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVE,		"Gravar",	tb_save_xpm,		NULL,	"Gravar documento")
+	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVEAS,		"Gravar como",	tb_save_as_xpm,		NULL,	"Gravar documento com um nome diferente")
+	ToolbarLabel(AP_TOOLBAR_ID_FILE_PRINT,		"Imprimir",	tb_print_xpm,		NULL,	"Imprimir documento")
+	ToolbarLabel(AP_TOOLBAR_ID_FILE_PRINT_PREVIEW,	"Ver Antes",	tb_print_preview_xpm,	NULL,	"Ver documento antes de o imprimir")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_UNDO,		"Desfazer",	tb_undo_xpm,		NULL,	"Cancelar ltima aco")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REDO,		"Refazer",	tb_redo_xpm,		NULL,	"Refazer ltima aco cancelada")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_CUT,		"Corta",	tb_cut_xpm,		NULL,	"Cortar texto seleccionado")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_COPY,		"Copiar",	tb_copy_xpm,		NULL,	"Copiar texto seleccionado")
 	ToolbarLabel(AP_TOOLBAR_ID_EDIT_PASTE,		"Colar",	tb_paste_xpm,		NULL,	"Colar")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_HEADER,		"Editar Cabealho", tb_edit_editheader_xpm, NULL, "Editar o Cabealho")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_FOOTER,		"Editar Rodap", tb_edit_editfooter_xpm, NULL,	"Editar o Rodap")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REMOVEHEADER,	"Remover Cabealho", tb_edit_removeheader_xpm, NULL, "Remover o Cabealho")
-	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REMOVEFOOTER,	"Remover Rodap", tb_edit_removefooter_xpm, NULL, "Remover o Rodap")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_HEADER,		"Editar Cabealho", tb_edit_editheader_xpm, NULL, "Editar Cabealho")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_FOOTER,		"Editar Rodap", tb_edit_editfooter_xpm, NULL,	"Editar Rodap")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REMOVEHEADER,	"Remover Cabealho", tb_edit_removeheader_xpm, NULL, "Remover Cabealho")
+	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REMOVEFOOTER,	"Remover Rodap", tb_edit_removefooter_xpm, NULL, "Remover Rodap")
 	ToolbarLabel(AP_TOOLBAR_ID_SPELLCHECK,		"Ortografia",	tb_spellcheck_xpm,	NULL,	"Verificar a ortografia do documento")
-	ToolbarLabel(AP_TOOLBAR_ID_IMG,			"Inserir Imagem", tb_insert_graphic_xpm,NULL,	"Inserir uma imagem no documento")
+	ToolbarLabel(AP_TOOLBAR_ID_IMG,			"Inserir Imagem", tb_insert_graphic_xpm,NULL,	"Inserir imagem")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_STYLE,		"Estilo",	NoIcon,			NULL,	"Estilo")
-	ToolbarLabel(AP_TOOLBAR_ID_FMT_FONT,		"Tipo",		NoIcon,			NULL,	"Tipo da letra")
-	ToolbarLabel(AP_TOOLBAR_ID_FMT_SIZE,		"Tamanho",	NoIcon,			NULL,	"Tamanho do tipo da letra")
+	ToolbarLabel(AP_TOOLBAR_ID_FMT_FONT,		"Tipo",		NoIcon,			NULL,	"Tipo de letra")
+	ToolbarLabel(AP_TOOLBAR_ID_FMT_SIZE,		"Tamanho",	NoIcon,			NULL,	"Tamanho de letra")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_BOLD,		"Negrito",	tb_text_bold_xpm,	NULL,	"Negrito")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_ITALIC,		"Itlico",	tb_text_italic_xpm,	NULL,	"Itlico")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_UNDERLINE,	"Sublinhado",	tb_text_underline_S_xpm,NULL,	"Sublinhado")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_OVERLINE,	"Sobrelinhado",	tb_text_overline_xpm,	NULL,	"Sobrelinhado")
-	ToolbarLabel(AP_TOOLBAR_ID_FMT_STRIKE,		"Cortado",	tb_text_strikeout_xpm,	NULL,	"Cortado")
+	ToolbarLabel(AP_TOOLBAR_ID_FMT_STRIKE,		"Riscado",	tb_text_strikeout_xpm,	NULL,	"Riscado")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_TOPLINE,		"Linha Superior",tb_text_topline_pt_PT_xpm,	NULL,	"Linha Superior")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_BOTTOMLINE,	"Linha Inferior",tb_text_bottomline_pt_PT_xpm,NULL,	"Linha Inferior")
 	ToolbarLabel(AP_TOOLBAR_ID_HELP,		"Ajuda",	tb_help_xpm,		NULL,	"Ajuda")
@@ -99,20 +99,20 @@ BeginSetEnc(pt,PT,true,"iso-8859-1")
 
 	ToolbarLabel(AP_TOOLBAR_ID_VIEW_SHOWPARA,	"Ver Pargrafos", tb_view_showpara_xpm,	NULL,	"Ver/Esconder ")
 	ToolbarLabel(AP_TOOLBAR_ID_ZOOM,		"Zoom",		NoIcon,			NULL,	"Zoom")
-	ToolbarLabel(AP_TOOLBAR_ID_LISTS_BULLETS,	"Lista Pontuada",tb_lists_bullets_xpm,	NULL,	"Comear/Terminar listas pontuadas")
-	ToolbarLabel(AP_TOOLBAR_ID_LISTS_NUMBERS,	"Lista Numerada",tb_lists_numbers_xpm,	NULL,	"Comear/Terminar listas numeradas")
-	ToolbarLabel(AP_TOOLBAR_ID_COLOR_FORE,		"Cor",		tb_text_fgcolor_xpm,			NULL,	"Mudar a cor")
-	ToolbarLabel(AP_TOOLBAR_ID_COLOR_BACK,		"Cor de fundo",	tb_text_bgcolor_xpm,			NULL,	"Mudar a cor de fundo")
-	ToolbarLabel(AP_TOOLBAR_ID_INDENT,		"Indentar",	tb_text_indent_xpm,	NULL,	"Aumentar indentao do pargrafo")
-	ToolbarLabel(AP_TOOLBAR_ID_UNINDENT,		"Desindentar",	tb_text_unindent_xpm,	NULL,	"Diminuir a indentao do pargrafo")
+	ToolbarLabel(AP_TOOLBAR_ID_LISTS_BULLETS,	"Lista Pontuada",tb_lists_bullets_xpm,	NULL,	"Listas pontuadas")
+	ToolbarLabel(AP_TOOLBAR_ID_LISTS_NUMBERS,	"Lista Numerada",tb_lists_numbers_xpm,	NULL,	"Listas numeradas")
+	ToolbarLabel(AP_TOOLBAR_ID_COLOR_FORE,		"Cor",		tb_text_fgcolor_xpm,			NULL,	"Cor de texto")
+	ToolbarLabel(AP_TOOLBAR_ID_COLOR_BACK,		"Cor de fundo",	tb_text_bgcolor_xpm,			NULL,	"Cor de fundo")
+	ToolbarLabel(AP_TOOLBAR_ID_INDENT,		"Indentar",	tb_text_indent_xpm,	NULL,	"Aumentar indentao")
+	ToolbarLabel(AP_TOOLBAR_ID_UNINDENT,		"Desindentar",	tb_text_unindent_xpm,	NULL,	"Diminuir a indentao")
 
 #ifdef ABI_OPT_PERL
 	ToolbarLabel(AP_TOOLBAR_ID_SCRIPT_PLAY,		"Executar Script",tb_script_play_xpm,	NULL,	"Executar script")
 #endif
 
 #ifdef BIDI_ENABLED
-	ToolbarLabel(AP_TOOLBAR_ID_FMT_DIR_OVERRIDE_LTR,"Da Esquerda para a Direita", tb_text_direction_ltr_xpm,	NULL, "Forar orientao do texto da Esquerda para a Direita")
-	ToolbarLabel(AP_TOOLBAR_ID_FMT_DIR_OVERRIDE_RTL,"Da Direita para a Esquerda", tb_text_direction_rtl_xpm,	NULL, "Forar orientao do texto da Direita para a Esquerda")
+	ToolbarLabel(AP_TOOLBAR_ID_FMT_DIR_OVERRIDE_LTR,"Esquerda para a Direita", tb_text_direction_ltr_xpm,	NULL, "Forar orientao da Esquerda para a Direita")
+	ToolbarLabel(AP_TOOLBAR_ID_FMT_DIR_OVERRIDE_RTL,"Direita para a Esquerda", tb_text_direction_rtl_xpm,	NULL, "Forar orientao da Direita para a Esquerda")
 	ToolbarLabel(AP_TOOLBAR_ID_FMT_DOM_DIRECTION,	"Orientao do pargrafo",    tb_text_dom_direction_rtl_xpm,	NULL, "Forar orientao normal do pargrafo")
 #endif
 	// ... add others here ...
