@@ -165,9 +165,12 @@ Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_Style)
 	case AP_TOOLBAR_ID_FMT_STYLE:
 		{
 			const XML_Char * sz;
-
 			if (!pView->getStyle(&sz))
-				return s;
+			{
+				static const char * sz2 ="None";
+				*pszState = sz2;
+				s = EV_TIS_UseString;
+			}
 
 			if (sz)
 			{	
@@ -176,7 +179,12 @@ Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_Style)
 				*pszState = sz2;
 				s = EV_TIS_UseString;
 			}
-
+			else
+			{
+				static const char * sz2 ="None";
+				*pszState = sz2;
+				s = EV_TIS_UseString;
+			}
 			break;
 		}
 
@@ -184,7 +192,6 @@ Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_Style)
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		break;
 	}
-
 	return s;
 }
 
@@ -403,7 +410,7 @@ Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_SectionFmt)
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		break;
 	}
-	
+	s = EV_TIS_ZERO;
 	if (prop && val)
 	{
 		// get current block properties from pView
@@ -411,11 +418,11 @@ Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_SectionFmt)
 		const XML_Char * sz = NULL;
 
         bool bResult = pView->getSectionFormat(&props_in);
-        pView->draw(NULL);
 
         if (!bResult)
+		{
 			return s;
-
+		}
 		// NB: maybe *no* properties are consistent across the selection
 		if (props_in && props_in[0])
 			sz = UT_getAttribute(prop, props_in);
@@ -426,6 +433,10 @@ Defun_EV_GetToolbarItemState_Fn(ap_ToolbarGetState_SectionFmt)
 			{
 				s = EV_TIS_Toggled;
 			}
+			else
+			{
+				s = EV_TIS_ZERO;
+			}
 		}
 		
 		free(props_in);
