@@ -60,10 +60,12 @@
 
 #include "xap_Module.h"
 
+ABI_PLUGIN_DECLARE("HRText")
+
 // we use a reference-counted sniffer
 static IE_Exp_HRText_Sniffer * m_sniffer = 0;
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_register (XAP_ModuleInfo * mi)
 {
 
@@ -86,7 +88,7 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_unregister (XAP_ModuleInfo * mi)
 {
 	mi->name = 0;
@@ -106,7 +108,7 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
 								 UT_uint32 release)
 {
@@ -263,7 +265,7 @@ void s_HRText_Listener::_openTag(PT_AttrPropIndex api)
 		const XML_Char * szListID;
 
 		if (
-		   (pAP->getAttribute((XML_Char*)"style", szValue))
+		   (pAP->getAttribute((XML_Char*)PT_STYLE_ATTRIBUTE_NAME, szValue))
 		   )
 		{
 			if(pAP->getAttribute((XML_Char*)"listid", szListID) &&
