@@ -18,6 +18,9 @@
  */
 
 
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <fcntl.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -29,6 +32,7 @@
 #include "ut_hash.h"
 #include "ut_units.h"
 #include "ut_wctomb.h"
+#include "ut_path.h"
 #include "pt_Types.h"
 #include "fd_Field.h"
 #include "ie_exp_HTML.h"
@@ -57,11 +61,13 @@
 
 #include "xap_Module.h"
 
+ABI_PLUGIN_DECLARE("HTML")
+
 // we use a reference-counted sniffer
 static IE_Exp_HTML_Sniffer * m_sniffer = 0;
 static IE_Exp_HTML4_Sniffer * m_4sniffer = 0;
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_register (XAP_ModuleInfo * mi)
 {
 
@@ -87,7 +93,7 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_unregister (XAP_ModuleInfo * mi)
 {
 	mi->name = 0;
@@ -108,14 +114,14 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	}
 
 	if(!m_4sniffer->unref())
-	  {
+	{
 	    m_4sniffer = 0;
-	  }
+	}
 
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
 								 UT_uint32 release)
 {
@@ -262,6 +268,7 @@ protected:
 	UT_uint16		m_iListDepth;	// 0 corresponds to not in a list
 	UT_uint16		m_iPrevListDepth;
 	UT_Stack		m_utsListType;
+	UT_Vector		m_utvDataIDs;	// list of data ids for image enumeration
         UT_uint16               m_iImgCnt;
 	UT_Wctomb		m_wmctomb;
 };
@@ -342,34 +349,47 @@ void s_HTML_Listener::_closeTag(void)
 	{
 		if(!m_bWroteText)
 		{
-			m_pie->write("<br />\r\n");
+			if (!m_bIs4)
+		    {
+				m_pie->write("<br />\r\n");
+		    }
+			else
+		    {
+				m_pie->write("<br>\r\n");
+		    }
 		}
 		m_pie->write("</p>\r\n");
 	}
-
-	else if(m_iBlockType == BT_HEADING1)
+	else if(m_iBlockType == BT_HEADING1) 
+	{
 		m_pie->write("</h1>\r\n");
-
+	}
 	else if(m_iBlockType == BT_HEADING2)
+	{
 		m_pie->write("</h2>\r\n");
-
+	}
 	else if(m_iBlockType == BT_HEADING3)
+	{
 		m_pie->write("</h3>\r\n");
-
+	}
 	else if(m_iBlockType == BT_BLOCKTEXT)
+	{
 		m_pie->write("</blockquote>\r\n");
-
+	}
 	else if(m_iBlockType == BT_PLAINTEXT)
+	{
 		m_pie->write("</pre>\r\n");
-
+	}
 	else if(m_iBlockType == BT_NUMBEREDLIST || m_iBlockType == BT_BULLETLIST)
-	{	/* do nothing, lists are handled differently, as they have multiple tags */ }
-
-        // Add "catchall" for now
-
-	else
-	  m_pie->write("</p>\r\n");
-
+	{	
+/* do nothing, lists are handled differently, as they have multiple tags */ 
+	}
+	// Add "catchall" for now
+ 	else
+	{
+		m_pie->write("</p>\r\n");
+	}
+	
 	m_bInBlock = false;
 	return;
 }
@@ -401,14 +421,14 @@ void s_HTML_Listener::_openTag(PT_AttrPropIndex api)
 		UT_uint16 *popped, *pushed;
 
 		if (
-		   (pAP->getAttribute("style", szValue) ||
-		    pAP->getAttribute("listid", szListID))
+		   (pAP->getAttribute(PT_STYLE_ATTRIBUTE_NAME, szValue) ||
+		   	(pAP->getAttribute(PT_LISTID_ATTRIBUTE_NAME, szListID) && 
+			 0 != UT_strcmp(szListID, "0")))
 		   )
 		{
-			if(pAP->getAttribute("listid", szListID) &&
-			   0 != UT_strcmp(szListID, "0"))
+			if(pAP->getAttribute(PT_LISTID_ATTRIBUTE_NAME, szListID))
 			{	// we're in a list
-				if(!pAP->getAttribute("style", szValue)) szValue = szDefault;
+				if(!pAP->getAttribute(PT_STYLE_ATTRIBUTE_NAME, szValue)) szValue = szDefault;
 				pAP->getAttribute("level", szLevel);
 				m_iListDepth = atoi((const char*) szLevel);
 				if(!pAP->getProperty("list-style", szStyleType))
@@ -661,8 +681,20 @@ void s_HTML_Listener::_openTag(PT_AttrPropIndex api)
 				|| pAP->getProperty("margin-top", szValue)
 				|| pAP->getProperty("margin-left", szValue)
 				|| pAP->getProperty("margin-right", szValue)
-				|| pAP->getProperty("text-indent", szValue)) )
+				|| pAP->getProperty("text-indent", szValue) 
+#ifdef BIDI_ENABLED
+				|| pAP->getProperty("dom-dir", szValue)
+#endif
+))
 		{
+#ifdef BIDI_ENABLED
+			if(pAP->getProperty("dom-dir", szValue))
+			{
+				m_pie->write(" dir=\"");
+				m_pie->write((char*)szValue);
+				m_pie->write("\"");
+			}
+#endif
 			bool validProp = false;
 			if(pAP->getProperty("text-align", szValue))
 			{
@@ -735,21 +767,23 @@ void s_HTML_Listener::_openTag(PT_AttrPropIndex api)
 				css = true;
 			}
 
-			if(validProp) m_pie->write("\"");
+			if(validProp) 
+			  m_pie->write("\"");
 		}
 	}
 	else 
 	{
-
+		
 		// <p> with no style attribute, and no properties either
 
-	  m_iBlockType = BT_NORMAL;
-	  m_pie->write("<p");
-	  wasWritten = true;
+		m_iBlockType = BT_NORMAL;
+		m_pie->write("<p");
+		wasWritten = true;
 	}
 	if (wasWritten)
-	  m_pie->write(">");
-
+	{
+		m_pie->write(">");
+	}
 	m_bInBlock = true;
 }
 
@@ -844,11 +878,13 @@ void s_HTML_Listener::_openSpan(PT_AttrPropIndex api)
 	
 	bool span = false;
 	bool textD = false;
+#ifdef BIDI_ENABLED
+	bool bDir = false;
+#endif
 	
 	if (bHaveProp && pAP)
 	{
 		const XML_Char * szValue;
-		
 		if (
 			(pAP->getProperty("font-weight", szValue))
 			&& !UT_strcmp(szValue, "bold")
@@ -1135,7 +1171,7 @@ void s_HTML_Listener::_openSpan(PT_AttrPropIndex api)
 		char* szStyle = NULL;
 		const XML_Char * pStyle;
 		PD_Style* s = NULL;
-		bool fnd = pAP->getAttribute("style", pStyle);
+		bool fnd = pAP->getAttribute(PT_STYLE_ATTRIBUTE_NAME, pStyle);
 		if(pStyle && fnd)
 		{
 			szStyle = removeWhiteSpace((const char *)pStyle);
@@ -1143,10 +1179,45 @@ void s_HTML_Listener::_openSpan(PT_AttrPropIndex api)
 		}
 
 		m_bInSpan = true;
+#ifdef BIDI_ENABLED
+/*
+	if the dir-override is set, or dir is 'rtl' or 'ltr', we will output
+	the dir property; however, this property cannot be within a style 
+	sheet, so anything that needs to be added to this code and belongs 
+	withing a style property must be above us; further it should be noted 
+	that there is a good chance that the html browser will not handle it 
+	correctly. For instance IE will take dir=rtl as an indication that 
+	the span should have rtl placement on a line, but it will ignore this 
+	value when printing the actual span.
+*/
+		if(!span && (pAP->getProperty("dir-override", szValue) || pAP->getProperty("dir", szValue)))
+		{
+			if(*szValue == 'r' || *szValue == 'l')
+			{
+				m_pie->write("<span dir=\"");
+				m_pie->write(szValue);
+				bDir = true;
+				span = true;
+			}
+		}
 
+#endif
 		if (span)
 		{
 			m_pie->write("\"");
+#ifdef BIDI_ENABLED
+			if (!bDir && (pAP->getProperty("dir-override", szValue) || pAP->getProperty("dir", szValue)))
+			{
+				if(*szValue == 'r' || *szValue == 'l')
+				{
+					m_pie->write(" dir=\"");
+					m_pie->write(szValue);
+					bDir = true;
+					m_pie->write("\"");
+				}
+			}
+#endif
+
 			if(szStyle)
 			{
 				m_pie->write(" class=\"");
@@ -1191,12 +1262,12 @@ void s_HTML_Listener::_closeSpan(void)
 		    || (pAP->getProperty("font-family", szValue))
 			)
 		{
-		  closeSpan = true;
+			closeSpan = true;
 		}
-
+		
 		if (pAP->getProperty("text-position", szValue))
 		{
-		  closeSpan = true;
+			closeSpan = true;
 		}
 
 		if (
@@ -1204,7 +1275,7 @@ void s_HTML_Listener::_closeSpan(void)
 			&& UT_strcmp(szValue, "none")
 			)
 		{
-		  closeSpan = true;
+			closeSpan = true;
 		}
 
 		if (
@@ -1212,7 +1283,7 @@ void s_HTML_Listener::_closeSpan(void)
 			&& !UT_strcmp(szValue, "italic")
 			)
 		{
-		  closeSpan = true;
+			closeSpan = true;
 		}
 		
 		if (
@@ -1220,18 +1291,18 @@ void s_HTML_Listener::_closeSpan(void)
 			&& !UT_strcmp(szValue, "bold")
 			)
 		{
-		  closeSpan = true;
+			closeSpan = true;
 		}
 
-		if(pAP->getAttribute("style", szValue))
+		if(pAP->getAttribute(PT_STYLE_ATTRIBUTE_NAME, szValue))
 		{
 			closeSpan = true;
 		}
 
 		if (closeSpan)
-		  {
+		{
 		    m_pie->write("</span>");
-		  }
+		}
 
 		m_pAP_Span = NULL;
 	}
@@ -1288,20 +1359,27 @@ void s_HTML_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 		case '\t':
 		  // try to honor multiple spaces
 
-		  if(m_bNextIsSpace)
-		    {
+			if(m_bNextIsSpace)
+			{
 				sBuf += "&nbsp;";
 				pData++;
-		    }
-		  else
-		    {
+			}
+			else
+			{
 				sBuf += *pData;
 				pData++;
-		    }
-		  break;
+			}
+			break;
 
 		case UCS_LF:			// LF -- representing a Forced-Line-Break
-			sBuf += "<br />";
+			if (!m_bIs4)
+			{
+				sBuf += "<br />";
+			}
+			else
+			{
+				sBuf += "<br>";
+			}
 			pData++;
 			break;
 
@@ -1311,6 +1389,32 @@ void s_HTML_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 			break;						// TODO: This handles apostrophes
 										// (smart single right quotes)
 										// what about the other types?
+		case UCS_LQUOTE:
+			sBuf += "\'";
+			pData++;
+			break;
+
+		case UCS_RDBLQUOTE:
+			sBuf += "&rdquo;";
+			pData++;
+			break;
+
+		case UCS_LDBLQUOTE:
+			sBuf += "&ldquo;";
+			pData++;
+			break;
+
+		case UCS_EN_DASH:
+		case UCS_EM_DASH:
+			sBuf += "-";
+			pData++;
+			break;
+
+		case UCS_FF:					// page break, convert to line break
+			sBuf += "<br />";
+			pData++;
+			break;
+		
 		default:
 			if (*pData > 0x007f)
 			{
@@ -1380,6 +1484,10 @@ bool s_HTML_Listener::_inherits(const char* style, const char* from)
 		if(pStyle && pStyle->getBasedOn())
 		{
 			pStyle = pStyle->getBasedOn();
+//
+// The name of the style is stored in the PT_NAME_ATTRIBUTE_NAME attribute within the
+// style
+//
 			pStyle->getAttribute(PT_NAME_ATTRIBUTE_NAME, 
 								 pName);
 			szName = removeWhiteSpace(pName);
@@ -1406,6 +1514,10 @@ void s_HTML_Listener::_outputInheritanceLine(const char* ClassName)
 			pBasedOn = pStyle->getBasedOn();
 			if(pBasedOn)
 			{
+//
+// The name of the style is stored in the PT_NAME_ATTRIBUTE_NAME attribute within the
+// style
+//
 				pBasedOn->getAttribute(PT_NAME_ATTRIBUTE_NAME, szName);
 				
 				UT_ASSERT((szName));
@@ -1429,36 +1541,43 @@ void s_HTML_Listener::_outputBegin(PT_AttrPropIndex api)
 
 	// we always encode as UTF-8
 	if ( !m_bIs4 )
-	  {
+	{
 	    m_pie->write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\r\n");
 	    m_pie->write("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\r\n");
-	  }
+	}
 	else
-	  {
+	{
 	    m_pie->write("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\" \"http://www.w3.org/TR/REC-html40/loose.dtd\">\r\n");
-	  }
-
+	}
+	
 	m_pie->write("<!-- ================================================================================  -->\r\n");
 	m_pie->write("<!-- This HTML file was created by AbiWord.                                            -->\r\n");
 	m_pie->write("<!-- AbiWord is a free, Open Source word processor.                                    -->\r\n");
 	m_pie->write("<!-- You may obtain more information about AbiWord at www.abisource.com                -->\r\n");
 	m_pie->write("<!-- ================================================================================  -->\r\n");
 	m_pie->write("\r\n");
-
+	
 	if ( !m_bIs4 )
-	  {
+	{
 	    m_pie->write("<html xmlns=\"http://www.w3.org/1999/xhtml\">\r\n");
-	  }
+	}
 	else
-	  {
+	{
 	    m_pie->write("<html>\r\n");
-	  }
-
+	}
+	
 	m_pie->write("<head>\r\n");
-
+	
 	// we always encode as UTF-8
-	m_pie->write("<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\" />\r\n");
-
+	if ( !m_bIs4 )
+	{
+	    m_pie->write("<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\" />\r\n");
+	}
+	else
+	{
+	    m_pie->write("<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\" >\r\n");
+	}
+	
 	m_pie->write("<title>");
 	m_pie->write(m_pie->getFileName());
 	m_pie->write("</title>\r\n");
@@ -1646,7 +1765,9 @@ s_HTML_Listener::~s_HTML_Listener()
 	{
 		DELETEP(popped);
 	}
-	
+
+	UT_VECTOR_PURGEALL(char*, m_utvDataIDs);
+
 	m_pie->write("</body>\r\n");
 	m_pie->write("</html>\r\n");
 }
@@ -1693,13 +1814,29 @@ bool s_HTML_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 			case PTO_Image:
 				// TODO: differentiate between SVG and PNG
 				// TODO: we do this in the img saving code
-	                        sprintf(buf, "-%d.png", m_iImgCnt++);
-				m_pie->write("<img alt=\"AbiWord Image");
-				m_pie->write(buf);
-				m_pie->write("\" src=\"");
-				m_pie->write(m_pie->getFileName());
-				m_pie->write(buf);
-				m_pie->write("\" />\r\n");
+
+				if(bHaveProp && pAP && pAP->getAttribute("dataid", szValue))
+				{
+					char* dataid = new char[strlen((char*) szValue)];
+					strcpy(dataid, (char*) szValue);
+
+					m_utvDataIDs.push_back(dataid);
+
+					sprintf(buf, "%d.png", m_iImgCnt++);
+					m_pie->write("<img alt=\"AbiWord Image");
+					m_pie->write(buf);
+					m_pie->write("\" src=\"");
+					m_pie->write(UT_basename(m_pie->getFileName()));
+					m_pie->write("_d/");
+					m_pie->write(buf);
+					// close the img tag with "/" only in XHTML
+					if (! m_bIs4) {
+						m_pie->write("\" />\r\n");
+					}
+					else {
+						m_pie->write("\">\r\n");
+					}
+				}
 				return true;
 
 			case PTO_Field:
@@ -1871,37 +2008,53 @@ UT_Error IE_Exp_HTML::_writeDocument(void)
 
 void s_HTML_Listener::_handleDataItems(void)
 {
-	const char * szName;
-   	const char * szMimeType;
+ 	const char * szName;
+	const char * szMimeType;
 	const UT_ByteBuf * pByteBuf;
-
+	
 	for (UT_uint32 k=0; (m_pDocument->enumDataItems(k,NULL,&szName,&pByteBuf,(void**)&szMimeType)); k++)
-	{	  	  
-	  FILE *fp;
-	  char fname [1024]; // EVIL EVIL bad hardcoded buffer size
-	  
-	  if (!UT_strcmp(szMimeType, "image/svg-xml"))
-	      sprintf(fname, "%s-%d.svg", m_pie->getFileName(), k);
-	  if (!UT_strcmp(szMimeType, "text/mathml"))
-	    sprintf(fname, "%s-%d.mathml", m_pie->getFileName(), k);
-	  else // PNG Image
-	    sprintf(fname, "%s-%d.png", m_pie->getFileName(), k);
-	  
-	  fp = fopen (fname, "wb+");
-	  
-	  if(!fp)
-	    continue;
-	  
-	  int cnt = 0, len = pByteBuf->getLength();
-	  
-	  while (cnt < len)
-	    {
-	      cnt += fwrite (pByteBuf->getPointer(cnt), sizeof(UT_Byte), len-cnt, fp);
-	    }
-	  
-	  fclose(fp);
+	{
+		UT_sint32 loc = -1;
+		for (UT_uint32 i = 0; i < m_utvDataIDs.getItemCount(); i++)
+		{
+			if(UT_strcmp((char*) m_utvDataIDs[i], szName) == 0)
+			{
+				loc = i;
+				break;
+			}
+		}
+		
+		if(loc > -1)
+		{
+			FILE *fp;
+			char fname [1024]; // EVIL EVIL bad hardcoded buffer size
+			
+			sprintf(fname, "%s_d", m_pie->getFileName());
+			int result = m_pDocument->getApp()->makeDirectory(fname, 0750);
+			
+			if (!UT_strcmp(szMimeType, "image/svg-xml"))
+				sprintf(fname, "%s/%d.svg", fname, loc);
+			if (!UT_strcmp(szMimeType, "text/mathml"))
+				sprintf(fname, "%s/%d.mathml", fname, loc);
+			else // PNG Image
+				sprintf(fname, "%s/%d.png", fname, loc);
+			
+			fp = fopen (fname, "wb+");
+			
+			if(!fp)
+				continue;
+			
+			int cnt = 0, len = pByteBuf->getLength();
+			
+			while (cnt < len)
+			{
+				cnt += fwrite (pByteBuf->getPointer(cnt), 
+							   sizeof(UT_Byte), len-cnt, fp);
+			}
+			
+			fclose(fp);
+		}
 	}
 	
 	return;
 }
-
