@@ -50,10 +50,12 @@
 
 #include "xap_Module.h"
 
+ABI_PLUGIN_DECLARE("LaTeX")
+
 // we use a reference-counted sniffer
 static IE_Exp_LaTeX_Sniffer * m_sniffer = 0;
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_register (XAP_ModuleInfo * mi)
 {
 
@@ -76,7 +78,7 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_unregister (XAP_ModuleInfo * mi)
 {
 	mi->name = 0;
@@ -96,7 +98,7 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
 								 UT_uint32 release)
 {
@@ -304,7 +306,7 @@ void s_LaTeX_Listener::_openParagraph(PT_AttrPropIndex api)
 	{
 		const XML_Char * szValue;
 
-		if (pAP->getAttribute("style", szValue))
+		if (pAP->getAttribute(PT_STYLE_ATTRIBUTE_NAME, szValue))
 		{
 			
 			if(0 == UT_strcmp(szValue, "Heading 1")) 
@@ -449,6 +451,7 @@ void s_LaTeX_Listener::_convertColor(char* szDest, const char* pszColor)
 		colors[i][2]=0;
 	}
 	setlocale (LC_NUMERIC, "C");
+	//FIXME: should use std_size_string here
 	sprintf (szDest, "%.3f,%.3f,%.3f",
 					strtol (&colors[0][0],NULL,16)/255.,
 					strtol (&colors[1][0],NULL,16)/255.,
