@@ -29,72 +29,10 @@
 #include "ie_imp_AbiWord_1.h"
 #include "ie_types.h"
 #include "pd_Document.h"
+#include "pd_Style.h"
 #include "ut_bytebuf.h"
 #include "xap_EncodingManager.h"
-
-/*****************************************************************/
-/*****************************************************************/
-
-#ifdef ENABLE_PLUGINS
-
-// completely generic code to allow this to be a plugin
-
-#include "xap_Module.h"
-
-#define SUPPORTS_ABI_VERSION(a,b,c) (((a==0)&&(b==7)&&(c==15)) ? 1 : 0)
-
-// we use a reference-counted sniffer
-static IE_Imp_AbiWord_1_Sniffer * m_sniffer = 0;
-
-ABI_FAR extern "C"
-int abi_plugin_register (XAP_ModuleInfo * mi)
-{
-
-	if (!m_sniffer)
-	{
-		m_sniffer = new IE_Imp_AbiWord_1_Sniffer ();
-	}
-	else
-	{
-		m_sniffer->ref();
-	}
-
-	mi->name = "AbiWord Importer";
-	mi->desc = "Import AbiWord Documents";
-	mi->version = "0.7.15";
-	mi->author = "Abi the Ant";
-	mi->usage = "No Usage";
-
-	IE_Imp::registerImporter (m_sniffer);
-	return 1;
-}
-
-ABI_FAR extern "C"
-int abi_plugin_unregister (XAP_ModuleInfo * mi)
-{
-	mi->name = 0;
-	mi->desc = 0;
-	mi->version = 0;
-	mi->author = 0;
-	mi->usage = 0;
-
-	UT_ASSERT (m_sniffer);
-
-	IE_Imp::unregisterImporter (m_sniffer);
-	if (!m_sniffer->unref())
-		m_sniffer = 0;
-
-	return 1;
-}
-
-ABI_FAR extern "C"
-int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
-								 UT_uint32 release)
-{
-	return SUPPORTS_ABI_VERSION(major, minor, release);
-}
-
-#endif
+#include "ut_misc.h"
 
 /*****************************************************************/
 /*****************************************************************/
@@ -422,11 +360,26 @@ void IE_Imp_AbiWord_1::_startElement(const XML_Char *name, const XML_Char **atts
 		return;
 
 	case TT_STYLE:
+	{
 		X_VerifyParseState(_PS_StyleSec);
 		m_parseState = _PS_Style;
-		X_CheckError(getDoc()->appendStyle(atts));
+//
+// Have to see if the style already exists. If it does, replace it with this.
+//
+		const XML_Char * szName = UT_getAttribute(PT_NAME_ATTRIBUTE_NAME,atts);
+		PD_Style * pStyle = NULL;
+		if(getDoc()->getStyle(szName, &pStyle))
+		{
+			X_CheckError(pStyle->addAttributes(atts));
+			pStyle->getBasedOn();
+			pStyle->getFollowedBy();
+		}
+		else
+		{
+			X_CheckError(getDoc()->appendStyle(atts));
+		}
 		return;
-		
+	}
 	case TT_LISTSECTION:
 		X_VerifyParseState(_PS_Doc);
 		m_parseState = _PS_ListSec;
