@@ -52,6 +52,9 @@
 // Of the ico, hps, ftc, lid, etc... are used in place of their "normal"
 // Counterparts
 //
+#ifdef BIDI_ENABLED
+#include "fribidi.h"
+#endif
 
 //
 // Forward decls. to wv's callbacks
@@ -189,10 +192,12 @@ s_mapPageIdToString (UT_uint16 id)
 
 #include "xap_Module.h"
 
+ABI_PLUGIN_DECLARE("MsWord")
+
 // we use a reference-counted sniffer
 static IE_Imp_MsWord_97_Sniffer * m_sniffer = 0;
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_register (XAP_ModuleInfo * mi)
 {
 
@@ -217,7 +222,7 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_unregister (XAP_ModuleInfo * mi)
 {
 	mi->name    = 0;
@@ -237,7 +242,7 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
 								 UT_uint32 release)
 {
@@ -359,7 +364,10 @@ IE_Imp_MsWord_97::~IE_Imp_MsWord_97()
 }
 
 IE_Imp_MsWord_97::IE_Imp_MsWord_97(PD_Document * pDocument)
-	: IE_Imp (pDocument), m_iImageCount (0), m_nSections(0), m_bSetPageSize(false)
+  : IE_Imp (pDocument), m_iImageCount (0), m_nSections(0), m_bSetPageSize(false), m_bIsLower(false)
+#ifdef BIDI_ENABLED
+	,m_pLastCharFmt(""), m_iPrevDir(-1), m_iCurrDir(-1)
+#endif	
 {
 }
 
@@ -473,7 +481,52 @@ void IE_Imp_MsWord_97::_flush ()
 
 void IE_Imp_MsWord_97::_appendChar (UT_UCSChar ch)
 {
-    m_pTextRun += ch;
+#ifdef BIDI_ENABLED
+	XML_Char * propsArray[3];
+	UT_String props;
+	m_iCurrDir = fribidi_get_type((FriBidiCharType) ch);
+	
+	propsArray[0] = (XML_Char *)"props";
+	propsArray[2] = 0;
+	
+	if(m_iCurrDir != m_iPrevDir)
+	{
+		xxx_UT_DEBUGMSG(("MS Word Importer: change of direction: prev %d, curr %d, UCS 0x%x\n", m_iPrevDir, m_iCurrDir, ch));
+		
+		props = m_pLastCharFmt;
+				
+		switch (m_iCurrDir)
+		{
+			case FRIBIDI_TYPE_L:
+					props += "dir:ltr";
+					break;
+			case FRIBIDI_TYPE_R:
+					props += "dir:rtl";
+					break;
+			default:
+					props += "dir:ntrl";
+					break;
+			//case -3:
+			//		props += "dir:ontrl";
+			//		break;
+		}
+		m_iPrevDir = m_iCurrDir;
+		
+		propsArray[1] = (XML_Char *)props.c_str();
+		
+		this->_flush();
+		
+		if (!getDoc()->appendFmt((const XML_Char **)propsArray))
+		{
+			UT_DEBUGMSG(("_appendChar: error appending character formatting\n"));
+		}
+
+	}
+#endif
+
+	if ( m_bIsLower )
+	  ch = UT_UCS_tolower ( ch );
+	m_pTextRun += ch;
 }
 
 /****************************************************************************/
@@ -1135,6 +1188,10 @@ int IE_Imp_MsWord_97::_beginChar (wvParseStruct *ps, UT_uint32 tag,
 	//
 	// TODO: set char tolower if fSmallCaps && fLowerCase, possibly some list stuff
 	//
+	if ( achp->fSmallCaps && achp->fLowerCase )
+	  m_bIsLower = true;
+	else
+	  m_bIsLower = false;
 
 	// flush any data in our character runs
 	this->_flush ();
@@ -1173,9 +1230,9 @@ int IE_Imp_MsWord_97::_beginChar (wvParseStruct *ps, UT_uint32 tag,
 
 	// Our textrun automatically sets "dir" for us. We just need too keep
 	// LTR runs separate from RTL runs
-
+	
 	if (achp->fBidi) {
-		// TODO: do we need to do anything?
+		//TODO: do we need to do anything?
 	}
 
 #endif
@@ -1283,6 +1340,11 @@ int IE_Imp_MsWord_97::_beginChar (wvParseStruct *ps, UT_uint32 tag,
 	propsArray[0] = (XML_Char *)"props";
 	propsArray[1] = (XML_Char *)props.c_str();
 	propsArray[2] = 0;
+
+#ifdef BIDI_ENABLED
+	m_pLastCharFmt = props;
+	m_pLastCharFmt += ";";
+#endif
 	if (!getDoc()->appendFmt((const XML_Char **)propsArray))
 	{
 		UT_DEBUGMSG(("DOM: error appending character formatting\n"));
