@@ -110,6 +110,12 @@ private:
 	bool                m_bSetPageSize;
 	UT_UCSChar m_command [FLD_SIZE];
 	UT_UCSChar m_argument [FLD_SIZE];
+	bool       m_bIsLower;
+#ifdef BIDI_ENABLED
+	UT_String			m_pLastCharFmt;
+	UT_sint32			m_iPrevDir;
+	UT_sint32			m_iCurrDir;
+#endif
 };
 
 #endif /* IE_IMP_MSWORD_H */
