@@ -61,11 +61,13 @@
 
 #include "xap_Module.h"
 
+ABI_PLUGIN_DECLARE("Psion")
+
 // we use a reference-counted sniffer
 static IE_Imp_Psion_Word_Sniffer * m_word_sniffer = 0;
 static IE_Imp_Psion_TextEd_Sniffer * m_texted_sniffer = 0;
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_register (XAP_ModuleInfo * mi)
 {
 
@@ -91,7 +93,7 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_unregister (XAP_ModuleInfo * mi)
 {
 	mi->name = 0;
@@ -113,7 +115,7 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	return 1;
 }
 
-ABI_FAR extern "C"
+ABI_FAR_CALL
 int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
 								 UT_uint32 release)
 {
