@@ -40,6 +40,7 @@
 #include "ie_exp_Applix.h"
 #include "ie_exp_XSL-FO.h"
 #include "ie_exp_ISCII.h"
+#include "ie_exp_KWord_1.h"
 
 #include "ie_imp_AbiWord_1.h"
 #include "ie_imp_GZipAbiWord.h"
@@ -55,7 +56,8 @@
 #include "ie_imp_XSL-FO.h"
 #include "ie_imp_Applix.h"
 #include "ie_imp_ISCII.h"
-#include "ie_imp_WordPerfect_6.h"
+#include "ie_imp_WordPerfect.h"
+#include "ie_imp_KWord_1.h"
 
 
 /*!
@@ -71,6 +73,11 @@ void IE_ImpExp_RegisterXP ()
 	IE_Imp::registerImporter(new IE_Imp_XSL_FO_Sniffer ());
 	IE_Imp::registerImporter(new IE_Imp_XHTML_Sniffer ());
 	IE_Imp::registerImporter(new IE_Imp_ISCII_Sniffer ());
+
+#ifdef DEBUG
+	IE_Imp::registerImporter(new IE_Imp_KWord_1_Sniffer ());
+#endif
+
 	IE_Imp::registerImporter(new IE_Imp_PalmDoc_Sniffer ());
 	IE_Imp::registerImporter(new IE_Imp_Psion_TextEd_Sniffer ());
 	IE_Imp::registerImporter(new IE_Imp_Psion_Word_Sniffer ());
@@ -78,7 +85,7 @@ void IE_ImpExp_RegisterXP ()
 	IE_Imp::registerImporter(new IE_Imp_Text_Sniffer ());
 	IE_Imp::registerImporter(new IE_Imp_EncodedText_Sniffer ());
 	IE_Imp::registerImporter(new IE_Imp_WML_Sniffer ());
-	IE_Imp::registerImporter(new IE_Imp_WordPerfect_6_Sniffer ());
+	IE_Imp::registerImporter(new IE_Imp_WordPerfect_Sniffer ());
 	IE_Imp::registerImporter(new IE_Imp_GZipAbiWord_Sniffer ());
 	
 	IE_Exp::registerExporter(new IE_Exp_AbiWord_1_Sniffer ());
@@ -92,6 +99,9 @@ void IE_ImpExp_RegisterXP ()
 	IE_Exp::registerExporter(new IE_Exp_HTML4_Sniffer ());
 	IE_Exp::registerExporter(new IE_Exp_HTML_Sniffer ());
 	IE_Exp::registerExporter(new IE_Exp_ISCII_Sniffer ());
+//#ifdef DEBUG
+	IE_Exp::registerExporter(new IE_Exp_KWord_1_Sniffer ());
+//#endif
 	IE_Exp::registerExporter(new IE_Exp_LaTeX_Sniffer ());
 	IE_Exp::registerExporter(new IE_Exp_PalmDoc_Sniffer ());
 	IE_Exp::registerExporter(new IE_Exp_Psion_TextEd_Sniffer ());
