@@ -9,7 +9,7 @@
 #include "wv.h"
 #include "getopt.h"
 
-#define VERSION "0.6.5"
+#define VERSION "0.6.7"
 
 /* strdup isn't declared in <string.h> for `gcc -ansi'; declare it here */
 extern char *strdup (const char *);
@@ -365,7 +365,7 @@ main (int argc, char **argv)
 
     if (ret)
       {
-	  wvError (("startup error\n"));
+	  wvError (("startup error #%d\n", ret));
 	  wvOLEFree ();
 	  return (-1);
       }
